@@ -70,7 +70,7 @@ int main(int argc, char *argv[])
 
         // adjust Doxyfile
         setField(code, "ALPHABETICAL_INDEX", "NO");
-        setField(code, "EXCLUDE_PATTERNS", "*/moc_* */mod_* */qdnslookup*");
+        setField(code, "EXCLUDE_PATTERNS", "*/moc_* */mod_* */qdnslookup* */*_p.h */QXmppCodec.cpp */QXmppSasl.cpp");
         setField(code, "FULL_PATH_NAMES", "NO");
         setField(code, "HIDE_UNDOC_CLASSES", "YES");
         setField(code, "GENERATE_LATEX", "NO");
@@ -82,6 +82,7 @@ int main(int argc, char *argv[])
                 QString::number((QXMPP_VERSION >> 16) & 0xff),
                 QString::number((QXMPP_VERSION >> 8) & 0xff),
                 QString::number(QXMPP_VERSION & 0xff)));
+        setField(code, "QUIET", "YES");
         setField(code, "RECURSIVE", "YES");
 
         // write doxyfile
@@ -106,6 +107,10 @@ int main(int argc, char *argv[])
         QString code = QString::fromUtf8(source.readAll());
         source.close();
 
+        // add links for RFCs
+        QRegExp rfcRegexp("(RFC ([0-9]{4})(: [^\\s.]+( [A-Z][^\\s.]*)*)?)");
+        code.replace(rfcRegexp, "<a href=\"http://www.rfc-editor.org/rfc/rfc\\2.txt\">\\1</a>");
+
         // add links for XEPs
         QRegExp regexp("(XEP-([0-9]{4})(: [^\\s.]+( [A-Z][^\\s.]*)*)?)");
         code.replace(regexp, "<a href=\"http://xmpp.org/extensions/xep-\\2.html\">\\1</a>");
