@@ -3,7 +3,7 @@ var searchData=
   ['abort',['abort',['../classQXmppTransferJob.html#a22d997eaa5f3f906ef4d9e311a0e3939',1,'QXmppTransferJob']]],
   ['aborterror',['AbortError',['../classQXmppTransferJob.html#abacb5103efd8148e13b9c616113366bda0e4b5001e71380ad5f06f68cec3a08d8',1,'QXmppTransferJob']]],
   ['accept',['accept',['../classQXmppCall.html#a0627637efc9efd57aada1ce783b94457',1,'QXmppCall::accept()'],['../classQXmppTransferJob.html#ae8a1b5cb89a012eb1f8e85b5079379c0',1,'QXmppTransferJob::accept(const QString &amp;filePath)'],['../classQXmppTransferJob.html#aeb89d694c0f604dd7c955ceeb5e4347d',1,'QXmppTransferJob::accept(QIODevice *output)']]],
-  ['acceptsubscription',['acceptSubscription',['../classQXmppRosterManager.html#a87034871f324d0a3d78305f558cc3e78',1,'QXmppRosterManager']]],
+  ['acceptsubscription',['acceptSubscription',['../classQXmppRosterManager.html#a0b8e48ba14b36a5ce3a04d8b3fe456ab',1,'QXmppRosterManager']]],
   ['action',['Action',['../classQXmppJingleIq.html#accfb8d2dec7f9ee9a8de7bff4f1de1ec',1,'QXmppJingleIq::Action()'],['../classQXmppMucRoom.html#acd3129293f69d7e7cdd91b65aae0606f',1,'QXmppMucRoom::Action()'],['../classQXmppJingleIq.html#aadd9b1aaba5d5e6edba0c539bf22bfb4',1,'QXmppJingleIq::action()']]],
   ['active',['Active',['../classQXmppMessage.html#aeaa3cc5ccb7d451067a80dd1f3c7099aa2a197e88be8355a853534c2342e64c48',1,'QXmppMessage']]],
   ['activestate',['ActiveState',['../classQXmppCall.html#a90205b5034613127d2c4adc6a0252759ac43dd016f3eb2141b9ee044c255afcb8',1,'QXmppCall']]],
@@ -11,17 +11,21 @@ var searchData=
   ['addcacertificates',['addCaCertificates',['../classQXmppServer.html#a96ac43ec46b09d23d60e5b874645d253',1,'QXmppServer::addCaCertificates()'],['../classQXmppSslServer.html#a16de688275b4967ce4aa688f5f8e5f75',1,'QXmppSslServer::addCaCertificates()']]],
   ['addcomponent',['addComponent',['../classQXmppIceConnection.html#ac98283e6c42dd6318575c2880fd2edd8',1,'QXmppIceConnection']]],
   ['addextension',['addExtension',['../classQXmppClient.html#a61ccf1c37ca3f26bfd14e65c8ecf1740',1,'QXmppClient::addExtension()'],['../classQXmppServer.html#af8faf560a73c3fbe4fad705753c09d40',1,'QXmppServer::addExtension()']]],
+  ['addincomingclient',['addIncomingClient',['../classQXmppServer.html#adc4c461cb514b5c5aba2d5d320f1d09d',1,'QXmppServer']]],
   ['addinvokableinterface',['addInvokableInterface',['../classQXmppRpcManager.html#a015ec2d968d2b4460325531157e8b0bf',1,'QXmppRpcManager']]],
   ['additem',['addItem',['../classQXmppRosterIq.html#ab7c8d7ec0b185f48e175afb00b8f72d5',1,'QXmppRosterIq::addItem()'],['../classQXmppRosterManager.html#a7039e2a5c0bf0504606356872cd7b47a',1,'QXmppRosterManager::addItem()']]],
   ['addremotecandidate',['addRemoteCandidate',['../classQXmppIceComponent.html#a63e4d233754452c3e81302b358a13026',1,'QXmppIceComponent::addRemoteCandidate()'],['../classQXmppIceConnection.html#a0a7f8f4176deddf2e2022f4634fbc08a',1,'QXmppIceConnection::addRemoteCandidate()']]],
+  ['address',['address',['../classQXmppVCardEmail.html#af8cddfc269875613436846dcf05937c1',1,'QXmppVCardEmail']]],
+  ['addresses',['addresses',['../classQXmppVCardIq.html#aa0bf01a9040b18e0043dfa8547b36f16',1,'QXmppVCardIq']]],
   ['addroom',['addRoom',['../classQXmppMucManager.html#a931a67884858d4440b9c307bae50d8a8',1,'QXmppMucManager']]],
   ['affiliation',['Affiliation',['../classQXmppMucItem.html#a3a0d58827ab4d535326fc6d3dbcbd417',1,'QXmppMucItem::Affiliation()'],['../classQXmppMucItem.html#a2c485ce387bac064704c7ed3e2cccd14',1,'QXmppMucItem::affiliation() const ']]],
+  ['after',['after',['../classQXmppResultSetQuery.html#aa45ce7f461dc7d38885f381211efe395',1,'QXmppResultSetQuery']]],
   ['allowedactions',['allowedActions',['../classQXmppMucRoom.html#a3b41defb3bcf48bf7ce51c8163aac803',1,'QXmppMucRoom']]],
   ['allowedactionschanged',['allowedActionsChanged',['../classQXmppMucRoom.html#ad48ffe7c58476c2f9f77f73f51002d78',1,'QXmppMucRoom']]],
   ['anymessage',['AnyMessage',['../classQXmppLogger.html#a932dbbd4f70a1e9c0ff8f452e61fc9b8a4d23e0e5cc611ed29c10ae10b60a1fb7',1,'QXmppLogger']]],
   ['anymethod',['AnyMethod',['../classQXmppTransferJob.html#a962582d3049909305277e54e2095c71ba3a44df5bc47241f7bdc3ba4ca5018032',1,'QXmppTransferJob']]],
-  ['archivechatreceived',['archiveChatReceived',['../classQXmppArchiveManager.html#a8e4b194bb348c6c9a5348e4ce4ad8249',1,'QXmppArchiveManager']]],
-  ['archivelistreceived',['archiveListReceived',['../classQXmppArchiveManager.html#a2c0b11bdb39bbf9eadbde3a7542cc99e',1,'QXmppArchiveManager']]],
+  ['archivechatreceived',['archiveChatReceived',['../classQXmppArchiveManager.html#a703aa568d0ec6a7ce604004247fd97ec',1,'QXmppArchiveManager']]],
+  ['archivelistreceived',['archiveListReceived',['../classQXmppArchiveManager.html#a664908d079afe2baeeb49396b5e53ede',1,'QXmppArchiveManager']]],
   ['arebookmarksreceived',['areBookmarksReceived',['../classQXmppBookmarkManager.html#ae61e6b96bd1e72019f9c96dd80bb6225',1,'QXmppBookmarkManager']]],
   ['arguments',['arguments',['../classQXmppRpcInvokeIq.html#a870ba44778b440a333f934979abfff34',1,'QXmppRpcInvokeIq']]],
   ['audiochannel',['audioChannel',['../classQXmppCall.html#aff2006c93114c3c4bcff232705658516',1,'QXmppCall']]],
@@ -31,5 +35,6 @@ var searchData=
   ['autojoin',['autoJoin',['../classQXmppBookmarkConference.html#a993f88a4d5eb798ef972b097996c83e4',1,'QXmppBookmarkConference']]],
   ['autoreconnectionenabled',['autoReconnectionEnabled',['../classQXmppConfiguration.html#a8b9aad6cb544bfc51529772d1ed7d0ab',1,'QXmppConfiguration']]],
   ['available',['Available',['../classQXmppPresence.html#a47ab8dd08436f9d7c90d2990678b5a6daee4c403679460358c9002562794059d3',1,'QXmppPresence']]],
-  ['away',['Away',['../classQXmppPresence_1_1Status.html#abd5503736600af94925c0a2aa988f459a32ca31a994d31951aadd18e1d0d1ae0a',1,'QXmppPresence::Status']]]
+  ['availablestatustype',['AvailableStatusType',['../classQXmppPresence.html#ad56af0f57b732c09b080b9347c4dba94',1,'QXmppPresence::AvailableStatusType()'],['../classQXmppPresence.html#a33aa276d9c31556f8616f6c9fd471f0e',1,'QXmppPresence::availableStatusType() const ']]],
+  ['away',['Away',['../classQXmppPresence.html#ad56af0f57b732c09b080b9347c4dba94acebcb202966ea59ea213459d36e2d949',1,'QXmppPresence']]]
 ];
