@@ -1,6 +1,8 @@
 var searchData=
 [
+  ['ban',['ban',['../classQXmppMucRoom.html#a1c4be76e72f4b3d91752e653e722ed7c',1,'QXmppMucRoom']]],
   ['barejid',['bareJid',['../classQXmppRosterIq_1_1Item.html#ab221fe068220e81efd0ca7ce8629b51d',1,'QXmppRosterIq::Item']]],
+  ['before',['before',['../classQXmppResultSetQuery.html#a18330d1eaafd1d3f5ce18fc6d53956b9',1,'QXmppResultSetQuery']]],
   ['bind',['bind',['../classQXmppIceConnection.html#a21afce5d6bab75567edb2765fb2dce11',1,'QXmppIceConnection']]],
   ['birthday',['birthday',['../classQXmppVCardIq.html#a2d2a9f093833db58aa1df9603c9d2146',1,'QXmppVCardIq']]],
   ['bits',['bits',['../classQXmppVideoFrame.html#a969344e616ca53851d1d2fa1664f66fe',1,'QXmppVideoFrame::bits()'],['../classQXmppVideoFrame.html#a11aed117d01a623679e48c0223b13a1a',1,'QXmppVideoFrame::bits() const ']]],
@@ -8,5 +10,6 @@ var searchData=
   ['bookmarks',['bookmarks',['../classQXmppBookmarkManager.html#a918afcea89ab482c2112f7cafa48eff9',1,'QXmppBookmarkManager']]],
   ['bookmarksreceived',['bookmarksReceived',['../classQXmppBookmarkManager.html#a6b4c3ebab3bc03e313dc3b5392394a6c',1,'QXmppBookmarkManager']]],
   ['both',['Both',['../classQXmppRosterIq_1_1Item.html#a0133cf9262cec7e299c4db7c247c5514ad7dc2c24e3f207106bad568b6d705df7',1,'QXmppRosterIq::Item']]],
+  ['bytesavailable',['bytesAvailable',['../classQXmppRtpAudioChannel.html#ab466e33fdac225754fce1403e76a67a8',1,'QXmppRtpAudioChannel']]],
   ['bytesperline',['bytesPerLine',['../classQXmppVideoFrame.html#a03da51f8e009d31cd57c399cf7708138',1,'QXmppVideoFrame']]]
 ];
