@@ -6,12 +6,13 @@ var searchData=
   ['callremotemethod',['callRemoteMethod',['../classQXmppRpcManager.html#a23b184ca351509255623563fa2b9e2b8',1,'QXmppRpcManager']]],
   ['callstarted',['callStarted',['../classQXmppCallManager.html#a41734eaa39a6216d39cc40b3991492d2',1,'QXmppCallManager']]],
   ['cancel',['Cancel',['../classQXmppDataForm.html#adab12c436b8c450e2b4f59da1aecadeead77068b14f4fc528cbf07a055db6eeda',1,'QXmppDataForm']]],
+  ['capabilities',['capabilities',['../classQXmppDiscoveryManager.html#a3c3e53c9eacfbe9b6bc53793543bce6e',1,'QXmppDiscoveryManager']]],
   ['capabilityext',['capabilityExt',['../classQXmppPresence.html#aec8f7ec4bc7ee9a6afcbd79445954d12',1,'QXmppPresence']]],
   ['capabilityhash',['capabilityHash',['../classQXmppPresence.html#abc586b332f1bfacdb99356b6fa66671f',1,'QXmppPresence']]],
   ['capabilitynode',['capabilityNode',['../classQXmppPresence.html#abeb42678d2eb51d805021239b6787e15',1,'QXmppPresence']]],
   ['capabilityver',['capabilityVer',['../classQXmppPresence.html#af4b39ee86352ec85f6dea9286a8cb7e7',1,'QXmppPresence']]],
   ['channels',['channels',['../classQXmppJinglePayloadType.html#a11c8291389457bfe986b8c738e0e49a3',1,'QXmppJinglePayloadType']]],
-  ['chat',['chat',['../classQXmppArchiveChatIq.html#af08964b43018061a77c1e20029eaba48',1,'QXmppArchiveChatIq::chat()'],['../classQXmppPresence_1_1Status.html#abd5503736600af94925c0a2aa988f459a8d26b12cff2559ffc1ceb022c5d2f768',1,'QXmppPresence::Status::Chat()']]],
+  ['chat',['chat',['../classQXmppArchiveChatIq.html#af08964b43018061a77c1e20029eaba48',1,'QXmppArchiveChatIq::chat()'],['../classQXmppPresence.html#ad56af0f57b732c09b080b9347c4dba94a284dd672032786aab31be99dd495a65d',1,'QXmppPresence::Chat()']]],
   ['chats',['chats',['../classQXmppArchiveListIq.html#a9a64466dafcd734555ce4406491c1e05',1,'QXmppArchiveListIq']]],
   ['checkpassword',['checkPassword',['../classQXmppPasswordChecker.html#a62ba10636417e503f936560f4f2910a8',1,'QXmppPasswordChecker']]],
   ['client',['client',['../classQXmppClientExtension.html#a2476cb1a20963d15d45d39f24a0c1198',1,'QXmppClientExtension']]],
@@ -19,6 +20,7 @@ var searchData=
   ['clientcategory',['clientCategory',['../classQXmppDiscoveryManager.html#a9c75d379114e62fcd329c8ae725c636b',1,'QXmppDiscoveryManager']]],
   ['clientconnected',['clientConnected',['../classQXmppServer.html#a8bfdd55f8e3769caf65b458d36467a99',1,'QXmppServer']]],
   ['clientdisconnected',['clientDisconnected',['../classQXmppServer.html#a378cea7ca6ab1bda5e1d5182010557f0',1,'QXmppServer']]],
+  ['clientinfoform',['clientInfoForm',['../classQXmppDiscoveryManager.html#a4cdb1648895f23878acdc8ef7684f6ad',1,'QXmppDiscoveryManager']]],
   ['clientname',['clientName',['../classQXmppDiscoveryManager.html#af49b9abb7f8704c0d79fd0ef7d0360fe',1,'QXmppDiscoveryManager::clientName()'],['../classQXmppVersionManager.html#a7c1398fd97ef8aed42d4f4304c8924fa',1,'QXmppVersionManager::clientName()']]],
   ['clientos',['clientOs',['../classQXmppVersionManager.html#a8e03cdf2737c1e1eed51ad739ca6d179',1,'QXmppVersionManager']]],
   ['clientpresence',['clientPresence',['../classQXmppClient.html#a2f7f555d11d5c45772d31d66834d7610',1,'QXmppClient']]],
@@ -27,11 +29,10 @@ var searchData=
   ['clientvcardreceived',['clientVCardReceived',['../classQXmppVCardManager.html#af98ad32a12efdae22c27add715a826c8',1,'QXmppVCardManager']]],
   ['clientversion',['clientVersion',['../classQXmppVersionManager.html#aebb3df968e68ca78ba8b487d88becc87',1,'QXmppVersionManager']]],
   ['clockrate',['clockrate',['../classQXmppJinglePayloadType.html#ac6f8856d83334360d8766b473dba301a',1,'QXmppJinglePayloadType']]],
-  ['close',['close',['../classQXmppRtpVideoChannel.html#ad89cde8a1e04f4327639f12a64ac25d4',1,'QXmppRtpVideoChannel::close()'],['../classQXmppIceComponent.html#a36435fa0ef3b19f2b18b1cf549992732',1,'QXmppIceComponent::close()'],['../classQXmppIceConnection.html#a8afca28f57aa276b618444e96331a2be',1,'QXmppIceConnection::close()'],['../classQXmppServer.html#a5b12956133786ce383ac2ae0716821be',1,'QXmppServer::close()']]],
+  ['close',['close',['../classQXmppRtpAudioChannel.html#a6a767d53335f777cb3fceb924b4b32de',1,'QXmppRtpAudioChannel::close()'],['../classQXmppRtpVideoChannel.html#ad89cde8a1e04f4327639f12a64ac25d4',1,'QXmppRtpVideoChannel::close()'],['../classQXmppIceComponent.html#a36435fa0ef3b19f2b18b1cf549992732',1,'QXmppIceComponent::close()'],['../classQXmppIceConnection.html#a8afca28f57aa276b618444e96331a2be',1,'QXmppIceConnection::close()'],['../classQXmppServer.html#a5b12956133786ce383ac2ae0716821be',1,'QXmppServer::close()']]],
   ['command',['command',['../classQXmppDialback.html#a7e771c31a7ba8c44fdd3e078f3b69521',1,'QXmppDialback::command() const '],['../classQXmppDialback.html#a0448107c56f892056f359013b80798bc',1,'QXmppDialback::Command()']]],
   ['component',['component',['../classQXmppJingleCandidate.html#a869b34fdeba74466e2cfdd69d31c5443',1,'QXmppJingleCandidate::component()'],['../classQXmppIceComponent.html#acecc3027c345fe1bfc1247107101aeab',1,'QXmppIceComponent::component()'],['../classQXmppIceConnection.html#ab75e321610c39ddc9aec5b20f36b5c8c',1,'QXmppIceConnection::component()']]],
   ['composing',['Composing',['../classQXmppMessage.html#aeaa3cc5ccb7d451067a80dd1f3c7099aa7804ac6c0c6848221acb67b9de0371d3',1,'QXmppMessage']]],
-  ['compressionmethod',['CompressionMethod',['../classQXmppConfiguration.html#a83074c11449a6d7a02f551e4494b5822',1,'QXmppConfiguration']]],
   ['conferences',['conferences',['../classQXmppBookmarkSet.html#a304e9a8e652b311853d66834a8fce6a8',1,'QXmppBookmarkSet']]],
   ['configuration',['configuration',['../classQXmppClient.html#a1cd44e6c54b54be4bf50cf3559786476',1,'QXmppClient::configuration()'],['../classQXmppOutgoingClient.html#a47676ce355fc5253af9a79c596a95431',1,'QXmppOutgoingClient::configuration()']]],
   ['configurationaction',['ConfigurationAction',['../classQXmppMucRoom.html#acd3129293f69d7e7cdd91b65aae0606fa4c1b38531dcf4fa97e1441e8334c9d13',1,'QXmppMucRoom']]],
@@ -44,5 +45,8 @@ var searchData=
   ['content',['content',['../classQXmppJingleIq.html#a19249357c437ca81e6d39e0434fcd90f',1,'QXmppJingleIq::content()'],['../classQXmppJingleIq.html#a118078aae1f72067abbc9096ac59d1ab',1,'QXmppJingleIq::content() const ']]],
   ['contents',['contents',['../classQXmppPubSubItem.html#a6079e555c862437a727647409a7912e4',1,'QXmppPubSubItem']]],
   ['core',['Core',['../group__Core.html',1,'']]],
-  ['create',['create',['../classQXmppServerPlugin.html#a5802a49843d86e341c7be21662b2c09e',1,'QXmppServerPlugin']]]
+  ['count',['count',['../classQXmppResultSetReply.html#aa6d8a4102269973ddd6d341b29d2ca12',1,'QXmppResultSetReply']]],
+  ['country',['country',['../classQXmppVCardAddress.html#ac55d402e158179fd016faf933714895c',1,'QXmppVCardAddress']]],
+  ['create',['create',['../classQXmppServerPlugin.html#a5802a49843d86e341c7be21662b2c09e',1,'QXmppServerPlugin']]],
+  ['csrc',['csrc',['../classQXmppRtpPacket.html#a10fb838efa95f0d2e42ca04a3d06ca1f',1,'QXmppRtpPacket']]]
 ];
