@@ -6,8 +6,9 @@ var searchData=
   ['datetimetostring',['datetimeToString',['../classQXmppUtils.html#a3ab27007d02693dfe26be892dd48f45c',1,'QXmppUtils']]],
   ['debug',['debug',['../classQXmppLoggable.html#adf78baaf99fba802edaa791fbbd34236',1,'QXmppLoggable']]],
   ['debugmessage',['DebugMessage',['../classQXmppLogger.html#a932dbbd4f70a1e9c0ff8f452e61fc9b8ad37e67a6433954474cdd1a44ee8d8bae',1,'QXmppLogger']]],
-  ['decode',['decode',['../classQXmppCodec.html#a5f5b22434aac2f693b9fbe444244ec96',1,'QXmppCodec::decode()'],['../classQXmppRtpPacket.html#af9d20509224aa4f27fc1c92fc87e9f58',1,'QXmppRtpPacket::decode()']]],
-  ['description',['description',['../classQXmppDataForm_1_1Field.html#a8b006128d764080cf2725649f63ae4e9',1,'QXmppDataForm::Field']]],
+  ['decode',['decode',['../classQXmppRtpPacket.html#af9d20509224aa4f27fc1c92fc87e9f58',1,'QXmppRtpPacket']]],
+  ['decoderformat',['decoderFormat',['../classQXmppRtpVideoChannel.html#a123733acb37a022a9c273eadaf5aa8fc',1,'QXmppRtpVideoChannel']]],
+  ['description',['description',['../classQXmppDataForm_1_1Field.html#a8b006128d764080cf2725649f63ae4e9',1,'QXmppDataForm::Field::description()'],['../classQXmppExtendedAddress.html#ab6c29726ab00157e5711ef3cf815d06a',1,'QXmppExtendedAddress::description()'],['../classQXmppVCardIq.html#aeedaf3f78a9bb61e3d8be8129466f73c',1,'QXmppVCardIq::description()']]],
   ['dialbackrequestreceived',['dialbackRequestReceived',['../classQXmppIncomingServer.html#a38a41b7076e423a4861b9a3eba035e98',1,'QXmppIncomingServer']]],
   ['dialbackresponsereceived',['dialbackResponseReceived',['../classQXmppOutgoingServer.html#a8ebbb372ca06478a9324c65539af74db',1,'QXmppOutgoingServer']]],
   ['digest',['digest',['../classQXmppPasswordReply.html#a93a2eae02ee07a478366306672ae51b3',1,'QXmppPasswordReply']]],
@@ -22,6 +23,6 @@ var searchData=
   ['discoveryidentities',['discoveryIdentities',['../classQXmppClientExtension.html#a9acf0693520c93ddc60c4994ffe09343',1,'QXmppClientExtension']]],
   ['discoveryitems',['discoveryItems',['../classQXmppServerExtension.html#ace0339dad1d50e98cc5109b4dc0e9212',1,'QXmppServerExtension']]],
   ['dispatch',['dispatch',['../classQXmppInvokable.html#aa7dc5639264fa76249d20a770219f5fb',1,'QXmppInvokable']]],
-  ['dnd',['DND',['../classQXmppPresence_1_1Status.html#abd5503736600af94925c0a2aa988f459a1df6742d4a5a07e49d5b149918328552',1,'QXmppPresence::Status']]],
+  ['dnd',['DND',['../classQXmppPresence.html#ad56af0f57b732c09b080b9347c4dba94a665a0346b1da2e5ddc521b47456ce729',1,'QXmppPresence']]],
   ['domain',['domain',['../classQXmppConfiguration.html#a80250a8b1f040328fbb3f9e4d640867b',1,'QXmppConfiguration::domain()'],['../classQXmppPasswordRequest.html#a4f71ebce0ec893aa1f3d7f41dc3bed95',1,'QXmppPasswordRequest::domain()'],['../classQXmppServer.html#a3d84689d629177cfb4fddc9798c5e05c',1,'QXmppServer::domain()']]]
 ];
