@@ -20,8 +20,8 @@ var searchData=
   ['localuser',['localUser',['../classQXmppIceConnection.html#aa02512f5c19bfc6514b9bf20698943ad',1,'QXmppIceConnection']]],
   ['log',['log',['../classQXmppLogger.html#a2e5e503ecd4400477f47dec915ac4e89',1,'QXmppLogger']]],
   ['logfilepath',['logFilePath',['../classQXmppLogger.html#a1be30b0f1390d14cb6d8535d4898a703',1,'QXmppLogger']]],
-  ['logger',['logger',['../classQXmppClient.html#ae5fca0867efe7e7fcae90cbbf10b8193',1,'QXmppClient::logger()'],['../classQXmppServer.html#a289bef14c92ff46f8ceb5b12a904d8be',1,'QXmppServer::logger()']]],
-  ['loggerchanged',['loggerChanged',['../classQXmppClient.html#a74a8754f3e14945e597d964442281e70',1,'QXmppClient']]],
+  ['logger',['logger',['../classQXmppClient.html#ae5fca0867efe7e7fcae90cbbf10b8193',1,'QXmppClient::logger()'],['../classQXmppServer.html#a0fa9d97d5be1f6429b35154c7621bd24',1,'QXmppServer::logger()']]],
+  ['loggerchanged',['loggerChanged',['../classQXmppClient.html#a74a8754f3e14945e597d964442281e70',1,'QXmppClient::loggerChanged()'],['../classQXmppServer.html#af49a15f76003d1e3b2ff280f55e1ca54',1,'QXmppServer::loggerChanged()']]],
   ['loggingtype',['LoggingType',['../classQXmppLogger.html#a9a52fe426322ef8e10e05b7092be6c20',1,'QXmppLogger::LoggingType()'],['../classQXmppLogger.html#a896f3347ee0c517db3404e07c6853187',1,'QXmppLogger::loggingType()']]],
   ['logmessage',['logMessage',['../classQXmppLoggable.html#a403fa46ba15c65da706e8188d4312a05',1,'QXmppLoggable::logMessage()'],['../classQXmppRtpAudioChannel.html#a56e695ad1815f25c70dbef6b7310007b',1,'QXmppRtpAudioChannel::logMessage()']]],
   ['logreceived',['logReceived',['../classQXmppLoggable.html#afcb384597aa4cdee1dad7d2ec50871f4',1,'QXmppLoggable']]],
