@@ -14,7 +14,7 @@ var searchData=
   ['nomessage',['NoMessage',['../classQXmppLogger.html#a932dbbd4f70a1e9c0ff8f452e61fc9b8aa1be17c113c6f22b82805e538c12cec9',1,'QXmppLogger']]],
   ['nomethod',['NoMethod',['../classQXmppTransferJob.html#a962582d3049909305277e54e2095c71ba6f69806ddd747d2d09d26f6642ac21e6',1,'QXmppTransferJob']]],
   ['none',['None',['../classQXmppDataForm.html#adab12c436b8c450e2b4f59da1aecadeea3239da22ddd2cfa5e6052d617cb7545f',1,'QXmppDataForm::None()'],['../classQXmppMessage.html#aeaa3cc5ccb7d451067a80dd1f3c7099aabe52ccd452233405cb3a9f86ce086236',1,'QXmppMessage::None()'],['../classQXmppRosterIq_1_1Item.html#a0133cf9262cec7e299c4db7c247c5514a57718bbef43da7d46f4c51473cf8dd81',1,'QXmppRosterIq::Item::None()']]],
-  ['nonsaslauthmechanism',['nonSASLAuthMechanism',['../classQXmppConfiguration.html#a4a2c891017fc79544a439ce6ce48fc71',1,'QXmppConfiguration::nonSASLAuthMechanism() const '],['../classQXmppConfiguration.html#acdc5d816a74551209d5c50557e90fda2',1,'QXmppConfiguration::NonSASLAuthMechanism()']]],
+  ['nonsaslauthmechanism',['NonSASLAuthMechanism',['../classQXmppConfiguration.html#acdc5d816a74551209d5c50557e90fda2',1,'QXmppConfiguration::NonSASLAuthMechanism()'],['../classQXmppConfiguration.html#a4a2c891017fc79544a439ce6ce48fc71',1,'QXmppConfiguration::nonSASLAuthMechanism() const ']]],
   ['nonsasldigest',['NonSASLDigest',['../classQXmppConfiguration.html#acdc5d816a74551209d5c50557e90fda2a97f33f490ab3d0bfdf717037551a62a3',1,'QXmppConfiguration']]],
   ['nonsaslplain',['NonSASLPlain',['../classQXmppConfiguration.html#acdc5d816a74551209d5c50557e90fda2a1edaa0616b19f8d6f7a711f37f672762',1,'QXmppConfiguration']]],
   ['notset',['NotSet',['../classQXmppRosterIq_1_1Item.html#a0133cf9262cec7e299c4db7c247c5514a5cbc5c1d6fd784f7c17437c7b6ebe544',1,'QXmppRosterIq::Item']]],
