@@ -1,30 +1,34 @@
 var searchData=
 [
-  ['parameters',['parameters',['../classQXmppVideoEncoder.html#a240118e5688b3efb5f0be47f6286b2af',1,'QXmppVideoEncoder::parameters()'],['../classQXmppJinglePayloadType.html#aab01af2f379b0b1b96fea2c8dcbdd2ce',1,'QXmppJinglePayloadType::parameters()']]],
+  ['parameters',['parameters',['../classQXmppJinglePayloadType.html#aab01af2f379b0b1b96fea2c8dcbdd2ce',1,'QXmppJinglePayloadType']]],
   ['paramtypes',['paramTypes',['../classQXmppInvokable.html#af45f378146e76bd487c7bc22c173d5b4',1,'QXmppInvokable']]],
   ['participantadded',['participantAdded',['../classQXmppMucRoom.html#a524f76903e60e14a3163301a3cd6d792',1,'QXmppMucRoom']]],
   ['participantchanged',['participantChanged',['../classQXmppMucRoom.html#a12bc2e165a6bd721ecf79a3fe9480176',1,'QXmppMucRoom']]],
+  ['participantfulljid',['participantFullJid',['../classQXmppMucRoom.html#a93fb5f2febc9cfb57b445d1d3b57d1d3',1,'QXmppMucRoom']]],
   ['participantpresence',['participantPresence',['../classQXmppMucRoom.html#af97a30f3f832a294cadd7b8644a1f441',1,'QXmppMucRoom']]],
   ['participantremoved',['participantRemoved',['../classQXmppMucRoom.html#a161afb360c1cd19819bfeb0579b9c940',1,'QXmppMucRoom']]],
   ['participants',['participants',['../classQXmppMucRoom.html#a8ebbaed22c263503552704ce308d8c42',1,'QXmppMucRoom']]],
-  ['password',['password',['../classQXmppMucRoom.html#a823200ee661315b757accce9da0313eb',1,'QXmppMucRoom::password()'],['../classQXmppConfiguration.html#ab03c0b84b6b866b10b562d0aded91140',1,'QXmppConfiguration::password()'],['../classQXmppPasswordRequest.html#abf2cc449121ce4ff2aafbe62cfe58401',1,'QXmppPasswordRequest::password()'],['../classQXmppPasswordReply.html#a9c219de5968b48f50722cee227bd9a9e',1,'QXmppPasswordReply::password()']]],
+  ['password',['password',['../classQXmppMucRoom.html#a823200ee661315b757accce9da0313eb',1,'QXmppMucRoom::password()'],['../classQXmppRegisterIq.html#a872b0576ecc47c3a3348f14790f13792',1,'QXmppRegisterIq::password()'],['../classQXmppConfiguration.html#ab03c0b84b6b866b10b562d0aded91140',1,'QXmppConfiguration::password()'],['../classQXmppPasswordRequest.html#abf2cc449121ce4ff2aafbe62cfe58401',1,'QXmppPasswordRequest::password()'],['../classQXmppPasswordReply.html#a9c219de5968b48f50722cee227bd9a9e',1,'QXmppPasswordReply::password()']]],
   ['passwordchecker',['passwordChecker',['../classQXmppServer.html#af4cc5e7fe77e1593e391bb5679a7c8f5',1,'QXmppServer']]],
   ['paused',['Paused',['../classQXmppMessage.html#aeaa3cc5ccb7d451067a80dd1f3c7099aac05ed50993dc8450e49249db87c809cf',1,'QXmppMessage']]],
+  ['payload',['payload',['../classQXmppRtpPacket.html#ac51105e2aeb00fc3a4c7db69a1bb7cc1',1,'QXmppRtpPacket']]],
   ['payloadtype',['payloadType',['../classQXmppRtpAudioChannel.html#a9b902a64c3cae0cfed07fece17c737e8',1,'QXmppRtpAudioChannel']]],
-  ['payloadtypeschanged',['payloadTypesChanged',['../classQXmppRtpVideoChannel.html#a0b5d2482a5f2f9caa326a359886f68ea',1,'QXmppRtpVideoChannel']]],
   ['peerreflexivetype',['PeerReflexiveType',['../classQXmppJingleCandidate.html#a6314b3ed7de59b68131db6ffab55fe7daa8c05f2daae9c29c2d066c54d3b8673c',1,'QXmppJingleCandidate']]],
   ['permissionsaction',['PermissionsAction',['../classQXmppMucRoom.html#acd3129293f69d7e7cdd91b65aae0606fa47093bf22ebdf16142a7711c31e8b508',1,'QXmppMucRoom']]],
   ['permissionsreceived',['permissionsReceived',['../classQXmppMucRoom.html#abc6d62be447548fe9f60a9a478d35028',1,'QXmppMucRoom']]],
+  ['phones',['phones',['../classQXmppVCardIq.html#ab9e923c99ee711143e06c12c250d677a',1,'QXmppVCardIq']]],
   ['photo',['photo',['../classQXmppVCardIq.html#a2046fd196e2b337ac2d292ca0e7635be',1,'QXmppVCardIq']]],
   ['photohash',['photoHash',['../classQXmppPresence.html#a2013bdab8a80ef7ed1c765d00f81ef86',1,'QXmppPresence']]],
   ['phototype',['photoType',['../classQXmppVCardIq.html#abc90cf1d0ea643f4c993ca7614420b9e',1,'QXmppVCardIq']]],
-  ['pixelformat',['pixelFormat',['../classQXmppVideoFrame.html#a55c875a1341fac1b907879fa24486674',1,'QXmppVideoFrame']]],
+  ['pixelformat',['pixelFormat',['../classQXmppVideoFrame.html#a55c875a1341fac1b907879fa24486674',1,'QXmppVideoFrame::pixelFormat() const '],['../classQXmppVideoFrame.html#a55cceb24be43a12d0d410a2a6b51c1fe',1,'QXmppVideoFrame::PixelFormat()']]],
   ['port',['port',['../classQXmppJingleCandidate.html#a4c7d8743389a252f7c81265df38bf7bd',1,'QXmppJingleCandidate::port()'],['../classQXmppConfiguration.html#aeca9614e66fb88a6967ebe6381e25fb7',1,'QXmppConfiguration::port()']]],
+  ['pos',['pos',['../classQXmppRtpAudioChannel.html#adae378ae5cea29ee0f9054566723103d',1,'QXmppRtpAudioChannel']]],
+  ['postcode',['postcode',['../classQXmppVCardAddress.html#a8bc8dc20efe2bb52a697065712dd190c',1,'QXmppVCardAddress']]],
   ['presencechanged',['presenceChanged',['../classQXmppRosterManager.html#ac95dd87aaa2c4cb61aa6ead2a17bc56e',1,'QXmppRosterManager']]],
   ['presencereceived',['presenceReceived',['../classQXmppClient.html#a10499b67cd25eed16f83118837fc5c29',1,'QXmppClient::presenceReceived()'],['../classQXmppOutgoingClient.html#a242817c83ce02d6f3c1956bfd15c3b15',1,'QXmppOutgoingClient::presenceReceived()']]],
   ['presencesubscribers',['presenceSubscribers',['../classQXmppServerExtension.html#a942c0a8411cabb7b4e13760e01e1ab70',1,'QXmppServerExtension']]],
   ['presencesubscriptions',['presenceSubscriptions',['../classQXmppServerExtension.html#a7340a5b3458e991b47dbd413ccaf13c4',1,'QXmppServerExtension']]],
-  ['priority',['priority',['../classQXmppJingleCandidate.html#abb44c0e24dafc2a13eca85786b573d9f',1,'QXmppJingleCandidate::priority()'],['../classQXmppPresence_1_1Status.html#a4cf0d60772318c6f876a626bfe1dcae1',1,'QXmppPresence::Status::priority()']]],
+  ['priority',['priority',['../classQXmppJingleCandidate.html#abb44c0e24dafc2a13eca85786b573d9f',1,'QXmppJingleCandidate::priority()'],['../classQXmppPresence.html#a0411a54e3f20e42b7511efa4f02e36bb',1,'QXmppPresence::priority()']]],
   ['probe',['Probe',['../classQXmppPresence.html#a47ab8dd08436f9d7c90d2990678b5a6da78bd49bb7dff200e67b1584aee994cd8',1,'QXmppPresence']]],
   ['progress',['progress',['../classQXmppTransferJob.html#a571b9a67cf4ad6d573c58a3039bb0433',1,'QXmppTransferJob']]],
   ['protocol',['protocol',['../classQXmppJingleCandidate.html#a6b23d5174e9b0d5a4fcbe701e46dd5d0',1,'QXmppJingleCandidate']]],
