@@ -21,24 +21,24 @@ var searchData=
   ['qxmppcallmanager',['QXmppCallManager',['../classQXmppCallManager.html',1,'QXmppCallManager'],['../classQXmppCallManager.html#a560d15be90eda576c32fc7765c4495e4',1,'QXmppCallManager::QXmppCallManager()']]],
   ['qxmppclient',['QXmppClient',['../classQXmppClient.html',1,'QXmppClient'],['../classQXmppClient.html#a6ba469fd893d18ae14a709c5d040b623',1,'QXmppClient::QXmppClient()']]],
   ['qxmppclientextension',['QXmppClientExtension',['../classQXmppClientExtension.html',1,'QXmppClientExtension'],['../classQXmppClientExtension.html#aec299452688f50431f1028668186e3ec',1,'QXmppClientExtension::QXmppClientExtension()']]],
-  ['qxmppcodec',['QXmppCodec',['../classQXmppCodec.html',1,'']]],
   ['qxmppconfiguration',['QXmppConfiguration',['../classQXmppConfiguration.html',1,'QXmppConfiguration'],['../classQXmppConfiguration.html#acd68380ad2353139a8c29087c40e4dcc',1,'QXmppConfiguration::QXmppConfiguration()'],['../classQXmppConfiguration.html#ac91c247c5ee60472abb5393f9e32d0f2',1,'QXmppConfiguration::QXmppConfiguration(const QXmppConfiguration &amp;other)']]],
   ['qxmppdataform',['QXmppDataForm',['../classQXmppDataForm.html',1,'QXmppDataForm'],['../classQXmppDataForm.html#a058f203f616dbffbd32043f509a9ff65',1,'QXmppDataForm::QXmppDataForm(QXmppDataForm::Type type=QXmppDataForm::None)'],['../classQXmppDataForm.html#a976fd7811d7f937fd2f9a7d313eb7ca8',1,'QXmppDataForm::QXmppDataForm(const QXmppDataForm &amp;other)']]],
   ['qxmppdialback',['QXmppDialback',['../classQXmppDialback.html',1,'QXmppDialback'],['../classQXmppDialback.html#a1aa371e5859efa4eb5a5a733f609db3e',1,'QXmppDialback::QXmppDialback()']]],
   ['qxmppdiscoverymanager',['QXmppDiscoveryManager',['../classQXmppDiscoveryManager.html',1,'']]],
   ['qxmppentitytimemanager',['QXmppEntityTimeManager',['../classQXmppEntityTimeManager.html',1,'']]],
+  ['qxmppextendedaddress',['QXmppExtendedAddress',['../classQXmppExtendedAddress.html',1,'QXmppExtendedAddress'],['../classQXmppExtendedAddress.html#a977ce245d062f5cb8398b02ecff76163',1,'QXmppExtendedAddress::QXmppExtendedAddress()'],['../classQXmppExtendedAddress.html#a2a88bb47091f713d6b8176ab2ee1101f',1,'QXmppExtendedAddress::QXmppExtendedAddress(const QXmppExtendedAddress &amp;)']]],
   ['qxmppicecomponent',['QXmppIceComponent',['../classQXmppIceComponent.html',1,'QXmppIceComponent'],['../classQXmppIceComponent.html#ac42db14e22921cac54b2e7e2e9624c3d',1,'QXmppIceComponent::QXmppIceComponent()']]],
   ['qxmppiceconnection',['QXmppIceConnection',['../classQXmppIceConnection.html',1,'QXmppIceConnection'],['../classQXmppIceConnection.html#a7d406bc9a1991257db34c493bc5780a7',1,'QXmppIceConnection::QXmppIceConnection()']]],
   ['qxmppincomingclient',['QXmppIncomingClient',['../classQXmppIncomingClient.html',1,'QXmppIncomingClient'],['../classQXmppIncomingClient.html#a4544a58d3047af1fb4b997055fae9447',1,'QXmppIncomingClient::QXmppIncomingClient()']]],
   ['qxmppincomingserver',['QXmppIncomingServer',['../classQXmppIncomingServer.html',1,'QXmppIncomingServer'],['../classQXmppIncomingServer.html#a35f13c6597f2c46fe220e7f9f612832c',1,'QXmppIncomingServer::QXmppIncomingServer()']]],
   ['qxmppinvokable',['QXmppInvokable',['../classQXmppInvokable.html',1,'QXmppInvokable'],['../classQXmppInvokable.html#ae3f2b1d6d85b4ec6c7565554491ce6e3',1,'QXmppInvokable::QXmppInvokable()']]],
-  ['qxmppiq',['QXmppIq',['../classQXmppIq.html',1,'QXmppIq'],['../classQXmppIq.html#a16db985e7cbf842dbca1cb94ec57c64f',1,'QXmppIq::QXmppIq()']]],
+  ['qxmppiq',['QXmppIq',['../classQXmppIq.html',1,'QXmppIq'],['../classQXmppIq.html#a16db985e7cbf842dbca1cb94ec57c64f',1,'QXmppIq::QXmppIq(QXmppIq::Type type=QXmppIq::Get)'],['../classQXmppIq.html#a64c242ce6d42d7013d53120c58be5da2',1,'QXmppIq::QXmppIq(const QXmppIq &amp;other)']]],
   ['qxmppjinglecandidate',['QXmppJingleCandidate',['../classQXmppJingleCandidate.html',1,'']]],
   ['qxmppjingleiq',['QXmppJingleIq',['../classQXmppJingleIq.html',1,'QXmppJingleIq'],['../classQXmppJingleIq.html#aeb7657fe2e9f6d5a9da2beef434625ff',1,'QXmppJingleIq::QXmppJingleIq()']]],
   ['qxmppjinglepayloadtype',['QXmppJinglePayloadType',['../classQXmppJinglePayloadType.html',1,'']]],
   ['qxmpploggable',['QXmppLoggable',['../classQXmppLoggable.html',1,'QXmppLoggable'],['../classQXmppLoggable.html#a05ad3142486bec62b2d58ad49b1d4005',1,'QXmppLoggable::QXmppLoggable()']]],
   ['qxmpplogger',['QXmppLogger',['../classQXmppLogger.html',1,'QXmppLogger'],['../classQXmppLogger.html#a103f204a149f91d7e2c4faf7d02d2266',1,'QXmppLogger::QXmppLogger()']]],
-  ['qxmppmessage',['QXmppMessage',['../classQXmppMessage.html',1,'QXmppMessage'],['../classQXmppMessage.html#aa51870c00e3ffadc8555e00e0153c136',1,'QXmppMessage::QXmppMessage()']]],
+  ['qxmppmessage',['QXmppMessage',['../classQXmppMessage.html',1,'QXmppMessage'],['../classQXmppMessage.html#aa51870c00e3ffadc8555e00e0153c136',1,'QXmppMessage::QXmppMessage(const QString &amp;from=&quot;&quot;, const QString &amp;to=&quot;&quot;, const QString &amp;body=&quot;&quot;, const QString &amp;thread=&quot;&quot;)'],['../classQXmppMessage.html#af73b605ad48ee6ecc111975f774c6edd',1,'QXmppMessage::QXmppMessage(const QXmppMessage &amp;other)']]],
   ['qxmppmessagereceiptmanager',['QXmppMessageReceiptManager',['../classQXmppMessageReceiptManager.html',1,'QXmppMessageReceiptManager'],['../classQXmppMessageReceiptManager.html#abd24b74a2784930429f1e9df1d7704fa',1,'QXmppMessageReceiptManager::QXmppMessageReceiptManager()']]],
   ['qxmppmucadminiq',['QXmppMucAdminIq',['../classQXmppMucAdminIq.html',1,'']]],
   ['qxmppmucitem',['QXmppMucItem',['../classQXmppMucItem.html',1,'']]],
@@ -50,9 +50,12 @@ var searchData=
   ['qxmpppasswordchecker',['QXmppPasswordChecker',['../classQXmppPasswordChecker.html',1,'']]],
   ['qxmpppasswordreply',['QXmppPasswordReply',['../classQXmppPasswordReply.html',1,'QXmppPasswordReply'],['../classQXmppPasswordReply.html#aee5c16b4954a41b183086f108df26971',1,'QXmppPasswordReply::QXmppPasswordReply()']]],
   ['qxmpppasswordrequest',['QXmppPasswordRequest',['../classQXmppPasswordRequest.html',1,'']]],
-  ['qxmpppresence',['QXmppPresence',['../classQXmppPresence.html',1,'QXmppPresence'],['../classQXmppPresence.html#a55df3a12d8d19870aa2c80bf132778c2',1,'QXmppPresence::QXmppPresence()']]],
+  ['qxmpppresence',['QXmppPresence',['../classQXmppPresence.html',1,'QXmppPresence'],['../classQXmppPresence.html#ab3facb1c108a346c1866f11133592601',1,'QXmppPresence::QXmppPresence(QXmppPresence::Type type=QXmppPresence::Available)'],['../classQXmppPresence.html#a74ef4824a0c7c70c095c9e783a3b55b4',1,'QXmppPresence::QXmppPresence(const QXmppPresence &amp;other)']]],
   ['qxmpppubsubiq',['QXmppPubSubIq',['../classQXmppPubSubIq.html',1,'']]],
   ['qxmpppubsubitem',['QXmppPubSubItem',['../classQXmppPubSubItem.html',1,'']]],
+  ['qxmppregisteriq',['QXmppRegisterIq',['../classQXmppRegisterIq.html',1,'']]],
+  ['qxmppresultsetquery',['QXmppResultSetQuery',['../classQXmppResultSetQuery.html',1,'']]],
+  ['qxmppresultsetreply',['QXmppResultSetReply',['../classQXmppResultSetReply.html',1,'']]],
   ['qxmpprosteriq',['QXmppRosterIq',['../classQXmppRosterIq.html',1,'']]],
   ['qxmpprostermanager',['QXmppRosterManager',['../classQXmppRosterManager.html',1,'QXmppRosterManager'],['../classQXmppRosterManager.html#aa96bd124e15813b402bc1de93f9e4f7b',1,'QXmppRosterManager::QXmppRosterManager()']]],
   ['qxmpprpcinvokeiq',['QXmppRpcInvokeIq',['../classQXmppRpcInvokeIq.html',1,'']]],
@@ -66,16 +69,17 @@ var searchData=
   ['qxmppserverplugin',['QXmppServerPlugin',['../classQXmppServerPlugin.html',1,'']]],
   ['qxmppsessioniq',['QXmppSessionIq',['../classQXmppSessionIq.html',1,'']]],
   ['qxmppsslserver',['QXmppSslServer',['../classQXmppSslServer.html',1,'QXmppSslServer'],['../classQXmppSslServer.html#af0ef7762cca74cc5f833f0891348e08d',1,'QXmppSslServer::QXmppSslServer()']]],
-  ['qxmppstanza',['QXmppStanza',['../classQXmppStanza.html',1,'QXmppStanza'],['../classQXmppStanza.html#aeda5073d2af6c52e78f127bca4306ace',1,'QXmppStanza::QXmppStanza()']]],
+  ['qxmppstanza',['QXmppStanza',['../classQXmppStanza.html',1,'QXmppStanza'],['../classQXmppStanza.html#aeda5073d2af6c52e78f127bca4306ace',1,'QXmppStanza::QXmppStanza(const QString &amp;from=QString(), const QString &amp;to=QString())'],['../classQXmppStanza.html#af8e4636d056c754347635ba26cd8d60c',1,'QXmppStanza::QXmppStanza(const QXmppStanza &amp;other)']]],
   ['qxmppstream',['QXmppStream',['../classQXmppStream.html',1,'QXmppStream'],['../classQXmppStream.html#a70a8f8a0734c3a681fb0079890d99786',1,'QXmppStream::QXmppStream()']]],
   ['qxmpptransferjob',['QXmppTransferJob',['../classQXmppTransferJob.html',1,'']]],
   ['qxmpptransfermanager',['QXmppTransferManager',['../classQXmppTransferManager.html',1,'QXmppTransferManager'],['../classQXmppTransferManager.html#aa88b03ffc2b9039a50bae7e79e759ed7',1,'QXmppTransferManager::QXmppTransferManager()']]],
   ['qxmpputils',['QXmppUtils',['../classQXmppUtils.html',1,'']]],
-  ['qxmppvcardiq',['QXmppVCardIq',['../classQXmppVCardIq.html',1,'QXmppVCardIq'],['../classQXmppVCardIq.html#a93c39e3c608a259c505ba0ecd841e0db',1,'QXmppVCardIq::QXmppVCardIq()']]],
+  ['qxmppvcardaddress',['QXmppVCardAddress',['../classQXmppVCardAddress.html',1,'QXmppVCardAddress'],['../classQXmppVCardAddress.html#ab31c2eab8fb090d6716515cfe0fad36b',1,'QXmppVCardAddress::QXmppVCardAddress()'],['../classQXmppVCardAddress.html#a2093d0ed8737c0f04ffa543c3943f0a9',1,'QXmppVCardAddress::QXmppVCardAddress(const QXmppVCardAddress &amp;other)']]],
+  ['qxmppvcardemail',['QXmppVCardEmail',['../classQXmppVCardEmail.html',1,'QXmppVCardEmail'],['../classQXmppVCardEmail.html#ac2d3a7f08975a9d6a395c8ed60d1a4ef',1,'QXmppVCardEmail::QXmppVCardEmail()'],['../classQXmppVCardEmail.html#a769b18f711a4bca0a6de8f7707e89a0b',1,'QXmppVCardEmail::QXmppVCardEmail(const QXmppVCardEmail &amp;other)']]],
+  ['qxmppvcardiq',['QXmppVCardIq',['../classQXmppVCardIq.html',1,'QXmppVCardIq'],['../classQXmppVCardIq.html#a93c39e3c608a259c505ba0ecd841e0db',1,'QXmppVCardIq::QXmppVCardIq(const QString &amp;bareJid=&quot;&quot;)'],['../classQXmppVCardIq.html#a7e09646833b005171d2f3564cb446e91',1,'QXmppVCardIq::QXmppVCardIq(const QXmppVCardIq &amp;other)']]],
   ['qxmppvcardmanager',['QXmppVCardManager',['../classQXmppVCardManager.html',1,'']]],
+  ['qxmppvcardphone',['QXmppVCardPhone',['../classQXmppVCardPhone.html',1,'QXmppVCardPhone'],['../classQXmppVCardPhone.html#ab8227e376f5aba012a8e05d6f09c7c6a',1,'QXmppVCardPhone::QXmppVCardPhone()'],['../classQXmppVCardPhone.html#acd06e5045a4f27ce29a0bf34b6d4653c',1,'QXmppVCardPhone::QXmppVCardPhone(const QXmppVCardPhone &amp;other)']]],
   ['qxmppversioniq',['QXmppVersionIq',['../classQXmppVersionIq.html',1,'']]],
   ['qxmppversionmanager',['QXmppVersionManager',['../classQXmppVersionManager.html',1,'']]],
-  ['qxmppvideodecoder',['QXmppVideoDecoder',['../classQXmppVideoDecoder.html',1,'']]],
-  ['qxmppvideoencoder',['QXmppVideoEncoder',['../classQXmppVideoEncoder.html',1,'']]],
   ['qxmppvideoframe',['QXmppVideoFrame',['../classQXmppVideoFrame.html',1,'QXmppVideoFrame'],['../classQXmppVideoFrame.html#ae33d6c7b73381921c6f6b70fa2b16cf9',1,'QXmppVideoFrame::QXmppVideoFrame()'],['../classQXmppVideoFrame.html#aa8af160798b29f2164e93b2f84b3de8e',1,'QXmppVideoFrame::QXmppVideoFrame(int bytes, const QSize &amp;size, int bytesPerLine, PixelFormat format)']]]
 ];
