@@ -2,7 +2,8 @@ var searchData=
 [
   ['warning',['warning',['../classQXmppLoggable.html#aed6488cb2ca9c636876e2444c635bd72',1,'QXmppLoggable']]],
   ['warningmessage',['WarningMessage',['../classQXmppLogger.html#a932dbbd4f70a1e9c0ff8f452e61fc9b8adb2cbaa9ae0daa021fa4feddf085910a',1,'QXmppLogger']]],
-  ['width',['width',['../classQXmppVideoFrame.html#a07853c0f2b50643a87473889cf0447e1',1,'QXmppVideoFrame']]],
+  ['width',['width',['../classQXmppDataForm_1_1Media.html#a355906089937067230b86d5b67d72db7',1,'QXmppDataForm::Media::width()'],['../classQXmppVideoFrame.html#a07853c0f2b50643a87473889cf0447e1',1,'QXmppVideoFrame::width()']]],
+  ['windowsliveaccesstoken',['windowsLiveAccessToken',['../classQXmppConfiguration.html#a96dac8e5867395e4229a57de23ce518b',1,'QXmppConfiguration']]],
   ['with',['with',['../classQXmppArchiveChat.html#ae44837a0cdc501426ed70c469f9f6eb4',1,'QXmppArchiveChat::with()'],['../classQXmppArchiveListIq.html#a3609669356d73ed933d874c15fbf0847',1,'QXmppArchiveListIq::with()'],['../classQXmppArchiveRemoveIq.html#ab815858ab3ae0a318e0b53269c7cfa48',1,'QXmppArchiveRemoveIq::with()'],['../classQXmppArchiveRetrieveIq.html#a034e30ec531789a1f77512a9001693b5',1,'QXmppArchiveRetrieveIq::with()']]],
   ['writeframe',['writeFrame',['../classQXmppRtpVideoChannel.html#a17673e645003e0ee9b011f7a8bcc8f64',1,'QXmppRtpVideoChannel']]]
 ];
