@@ -17,12 +17,12 @@ var searchData=
   ['qxmppcallmanager',['QXmppCallManager',['../classQXmppCallManager.html',1,'']]],
   ['qxmppclient',['QXmppClient',['../classQXmppClient.html',1,'']]],
   ['qxmppclientextension',['QXmppClientExtension',['../classQXmppClientExtension.html',1,'']]],
-  ['qxmppcodec',['QXmppCodec',['../classQXmppCodec.html',1,'']]],
   ['qxmppconfiguration',['QXmppConfiguration',['../classQXmppConfiguration.html',1,'']]],
   ['qxmppdataform',['QXmppDataForm',['../classQXmppDataForm.html',1,'']]],
   ['qxmppdialback',['QXmppDialback',['../classQXmppDialback.html',1,'']]],
   ['qxmppdiscoverymanager',['QXmppDiscoveryManager',['../classQXmppDiscoveryManager.html',1,'']]],
   ['qxmppentitytimemanager',['QXmppEntityTimeManager',['../classQXmppEntityTimeManager.html',1,'']]],
+  ['qxmppextendedaddress',['QXmppExtendedAddress',['../classQXmppExtendedAddress.html',1,'']]],
   ['qxmppicecomponent',['QXmppIceComponent',['../classQXmppIceComponent.html',1,'']]],
   ['qxmppiceconnection',['QXmppIceConnection',['../classQXmppIceConnection.html',1,'']]],
   ['qxmppincomingclient',['QXmppIncomingClient',['../classQXmppIncomingClient.html',1,'']]],
@@ -49,6 +49,9 @@ var searchData=
   ['qxmpppresence',['QXmppPresence',['../classQXmppPresence.html',1,'']]],
   ['qxmpppubsubiq',['QXmppPubSubIq',['../classQXmppPubSubIq.html',1,'']]],
   ['qxmpppubsubitem',['QXmppPubSubItem',['../classQXmppPubSubItem.html',1,'']]],
+  ['qxmppregisteriq',['QXmppRegisterIq',['../classQXmppRegisterIq.html',1,'']]],
+  ['qxmppresultsetquery',['QXmppResultSetQuery',['../classQXmppResultSetQuery.html',1,'']]],
+  ['qxmppresultsetreply',['QXmppResultSetReply',['../classQXmppResultSetReply.html',1,'']]],
   ['qxmpprosteriq',['QXmppRosterIq',['../classQXmppRosterIq.html',1,'']]],
   ['qxmpprostermanager',['QXmppRosterManager',['../classQXmppRosterManager.html',1,'']]],
   ['qxmpprpcinvokeiq',['QXmppRpcInvokeIq',['../classQXmppRpcInvokeIq.html',1,'']]],
@@ -67,11 +70,12 @@ var searchData=
   ['qxmpptransferjob',['QXmppTransferJob',['../classQXmppTransferJob.html',1,'']]],
   ['qxmpptransfermanager',['QXmppTransferManager',['../classQXmppTransferManager.html',1,'']]],
   ['qxmpputils',['QXmppUtils',['../classQXmppUtils.html',1,'']]],
+  ['qxmppvcardaddress',['QXmppVCardAddress',['../classQXmppVCardAddress.html',1,'']]],
+  ['qxmppvcardemail',['QXmppVCardEmail',['../classQXmppVCardEmail.html',1,'']]],
   ['qxmppvcardiq',['QXmppVCardIq',['../classQXmppVCardIq.html',1,'']]],
   ['qxmppvcardmanager',['QXmppVCardManager',['../classQXmppVCardManager.html',1,'']]],
+  ['qxmppvcardphone',['QXmppVCardPhone',['../classQXmppVCardPhone.html',1,'']]],
   ['qxmppversioniq',['QXmppVersionIq',['../classQXmppVersionIq.html',1,'']]],
   ['qxmppversionmanager',['QXmppVersionManager',['../classQXmppVersionManager.html',1,'']]],
-  ['qxmppvideodecoder',['QXmppVideoDecoder',['../classQXmppVideoDecoder.html',1,'']]],
-  ['qxmppvideoencoder',['QXmppVideoEncoder',['../classQXmppVideoEncoder.html',1,'']]],
   ['qxmppvideoframe',['QXmppVideoFrame',['../classQXmppVideoFrame.html',1,'']]]
 ];
