@@ -5,6 +5,7 @@ var searchData=
   ['callreceived',['callReceived',['../classQXmppCallManager.html#a91f0a7a4fd78c78be0c4a54ab23af65f',1,'QXmppCallManager']]],
   ['callremotemethod',['callRemoteMethod',['../classQXmppRpcManager.html#a23b184ca351509255623563fa2b9e2b8',1,'QXmppRpcManager']]],
   ['callstarted',['callStarted',['../classQXmppCallManager.html#a41734eaa39a6216d39cc40b3991492d2',1,'QXmppCallManager']]],
+  ['capabilities',['capabilities',['../classQXmppDiscoveryManager.html#a3c3e53c9eacfbe9b6bc53793543bce6e',1,'QXmppDiscoveryManager']]],
   ['capabilityext',['capabilityExt',['../classQXmppPresence.html#aec8f7ec4bc7ee9a6afcbd79445954d12',1,'QXmppPresence']]],
   ['capabilityhash',['capabilityHash',['../classQXmppPresence.html#abc586b332f1bfacdb99356b6fa66671f',1,'QXmppPresence']]],
   ['capabilitynode',['capabilityNode',['../classQXmppPresence.html#abeb42678d2eb51d805021239b6787e15',1,'QXmppPresence']]],
@@ -18,6 +19,7 @@ var searchData=
   ['clientcategory',['clientCategory',['../classQXmppDiscoveryManager.html#a9c75d379114e62fcd329c8ae725c636b',1,'QXmppDiscoveryManager']]],
   ['clientconnected',['clientConnected',['../classQXmppServer.html#a8bfdd55f8e3769caf65b458d36467a99',1,'QXmppServer']]],
   ['clientdisconnected',['clientDisconnected',['../classQXmppServer.html#a378cea7ca6ab1bda5e1d5182010557f0',1,'QXmppServer']]],
+  ['clientinfoform',['clientInfoForm',['../classQXmppDiscoveryManager.html#a4cdb1648895f23878acdc8ef7684f6ad',1,'QXmppDiscoveryManager']]],
   ['clientname',['clientName',['../classQXmppDiscoveryManager.html#af49b9abb7f8704c0d79fd0ef7d0360fe',1,'QXmppDiscoveryManager::clientName()'],['../classQXmppVersionManager.html#a7c1398fd97ef8aed42d4f4304c8924fa',1,'QXmppVersionManager::clientName()']]],
   ['clientos',['clientOs',['../classQXmppVersionManager.html#a8e03cdf2737c1e1eed51ad739ca6d179',1,'QXmppVersionManager']]],
   ['clientpresence',['clientPresence',['../classQXmppClient.html#a2f7f555d11d5c45772d31d66834d7610',1,'QXmppClient']]],
@@ -26,7 +28,7 @@ var searchData=
   ['clientvcardreceived',['clientVCardReceived',['../classQXmppVCardManager.html#af98ad32a12efdae22c27add715a826c8',1,'QXmppVCardManager']]],
   ['clientversion',['clientVersion',['../classQXmppVersionManager.html#aebb3df968e68ca78ba8b487d88becc87',1,'QXmppVersionManager']]],
   ['clockrate',['clockrate',['../classQXmppJinglePayloadType.html#ac6f8856d83334360d8766b473dba301a',1,'QXmppJinglePayloadType']]],
-  ['close',['close',['../classQXmppRtpVideoChannel.html#ad89cde8a1e04f4327639f12a64ac25d4',1,'QXmppRtpVideoChannel::close()'],['../classQXmppIceComponent.html#a36435fa0ef3b19f2b18b1cf549992732',1,'QXmppIceComponent::close()'],['../classQXmppIceConnection.html#a8afca28f57aa276b618444e96331a2be',1,'QXmppIceConnection::close()'],['../classQXmppServer.html#a5b12956133786ce383ac2ae0716821be',1,'QXmppServer::close()']]],
+  ['close',['close',['../classQXmppRtpAudioChannel.html#a6a767d53335f777cb3fceb924b4b32de',1,'QXmppRtpAudioChannel::close()'],['../classQXmppRtpVideoChannel.html#ad89cde8a1e04f4327639f12a64ac25d4',1,'QXmppRtpVideoChannel::close()'],['../classQXmppIceComponent.html#a36435fa0ef3b19f2b18b1cf549992732',1,'QXmppIceComponent::close()'],['../classQXmppIceConnection.html#a8afca28f57aa276b618444e96331a2be',1,'QXmppIceConnection::close()'],['../classQXmppServer.html#a5b12956133786ce383ac2ae0716821be',1,'QXmppServer::close()']]],
   ['command',['command',['../classQXmppDialback.html#a7e771c31a7ba8c44fdd3e078f3b69521',1,'QXmppDialback']]],
   ['component',['component',['../classQXmppJingleCandidate.html#a869b34fdeba74466e2cfdd69d31c5443',1,'QXmppJingleCandidate::component()'],['../classQXmppIceComponent.html#acecc3027c345fe1bfc1247107101aeab',1,'QXmppIceComponent::component()'],['../classQXmppIceConnection.html#ab75e321610c39ddc9aec5b20f36b5c8c',1,'QXmppIceConnection::component()']]],
   ['conferences',['conferences',['../classQXmppBookmarkSet.html#a304e9a8e652b311853d66834a8fce6a8',1,'QXmppBookmarkSet']]],
@@ -37,5 +39,7 @@ var searchData=
   ['connecttoserver',['connectToServer',['../classQXmppClient.html#afebe3b0955b81c6dd0e738db328cf06b',1,'QXmppClient::connectToServer(const QXmppConfiguration &amp;, const QXmppPresence &amp;initialPresence=QXmppPresence())'],['../classQXmppClient.html#a06cf985c0cb91ea9341c0558c01de5b4',1,'QXmppClient::connectToServer(const QString &amp;jid, const QString &amp;password)']]],
   ['content',['content',['../classQXmppJingleIq.html#a19249357c437ca81e6d39e0434fcd90f',1,'QXmppJingleIq::content()'],['../classQXmppJingleIq.html#a118078aae1f72067abbc9096ac59d1ab',1,'QXmppJingleIq::content() const ']]],
   ['contents',['contents',['../classQXmppPubSubItem.html#a6079e555c862437a727647409a7912e4',1,'QXmppPubSubItem']]],
+  ['count',['count',['../classQXmppResultSetReply.html#aa6d8a4102269973ddd6d341b29d2ca12',1,'QXmppResultSetReply']]],
+  ['country',['country',['../classQXmppVCardAddress.html#ac55d402e158179fd016faf933714895c',1,'QXmppVCardAddress']]],
   ['create',['create',['../classQXmppServerPlugin.html#a5802a49843d86e341c7be21662b2c09e',1,'QXmppServerPlugin']]]
 ];
