@@ -5,8 +5,9 @@ var searchData=
   ['datetimefromstring',['datetimeFromString',['../classQXmppUtils.html#a9ce223b82721daee833cff35e8b09464',1,'QXmppUtils']]],
   ['datetimetostring',['datetimeToString',['../classQXmppUtils.html#a3ab27007d02693dfe26be892dd48f45c',1,'QXmppUtils']]],
   ['debug',['debug',['../classQXmppLoggable.html#adf78baaf99fba802edaa791fbbd34236',1,'QXmppLoggable']]],
-  ['decode',['decode',['../classQXmppCodec.html#a5f5b22434aac2f693b9fbe444244ec96',1,'QXmppCodec::decode()'],['../classQXmppRtpPacket.html#af9d20509224aa4f27fc1c92fc87e9f58',1,'QXmppRtpPacket::decode()']]],
-  ['description',['description',['../classQXmppDataForm_1_1Field.html#a8b006128d764080cf2725649f63ae4e9',1,'QXmppDataForm::Field']]],
+  ['decode',['decode',['../classQXmppRtpPacket.html#af9d20509224aa4f27fc1c92fc87e9f58',1,'QXmppRtpPacket']]],
+  ['decoderformat',['decoderFormat',['../classQXmppRtpVideoChannel.html#a123733acb37a022a9c273eadaf5aa8fc',1,'QXmppRtpVideoChannel']]],
+  ['description',['description',['../classQXmppDataForm_1_1Field.html#a8b006128d764080cf2725649f63ae4e9',1,'QXmppDataForm::Field::description()'],['../classQXmppExtendedAddress.html#ab6c29726ab00157e5711ef3cf815d06a',1,'QXmppExtendedAddress::description()'],['../classQXmppVCardIq.html#aeedaf3f78a9bb61e3d8be8129466f73c',1,'QXmppVCardIq::description()']]],
   ['dialbackrequestreceived',['dialbackRequestReceived',['../classQXmppIncomingServer.html#a38a41b7076e423a4861b9a3eba035e98',1,'QXmppIncomingServer']]],
   ['dialbackresponsereceived',['dialbackResponseReceived',['../classQXmppOutgoingServer.html#a8ebbb372ca06478a9324c65539af74db',1,'QXmppOutgoingServer']]],
   ['digest',['digest',['../classQXmppPasswordReply.html#a93a2eae02ee07a478366306672ae51b3',1,'QXmppPasswordReply']]],
