@@ -1,10 +1,13 @@
 var searchData=
 [
   ['elementreceived',['elementReceived',['../classQXmppOutgoingClient.html#a9be28568b016d24502d2f766cf42cbba',1,'QXmppOutgoingClient::elementReceived()'],['../classQXmppIncomingClient.html#a6797577d34078238df80380b68e68aa8',1,'QXmppIncomingClient::elementReceived()'],['../classQXmppIncomingServer.html#a79308b406dc7b6a69e08f18fb6587bcc',1,'QXmppIncomingServer::elementReceived()']]],
-  ['email',['email',['../classQXmppVCardIq.html#afdbb733f0ea07c2ff47ad4cac30b0cad',1,'QXmppVCardIq']]],
-  ['encode',['encode',['../classQXmppCodec.html#ae0cbb7c499b944617f56d21d4059b365',1,'QXmppCodec::encode()'],['../classQXmppRtpPacket.html#aedc497730691065d46997202cfb78000',1,'QXmppRtpPacket::encode()']]],
+  ['email',['email',['../classQXmppRegisterIq.html#a3f65ada262f8fcc9165fec6b9074408a',1,'QXmppRegisterIq::email()'],['../classQXmppVCardIq.html#afdbb733f0ea07c2ff47ad4cac30b0cad',1,'QXmppVCardIq::email()']]],
+  ['emails',['emails',['../classQXmppVCardIq.html#a026d0950efc37e130f7bc27e88fb0386',1,'QXmppVCardIq']]],
+  ['encode',['encode',['../classQXmppRtpPacket.html#aedc497730691065d46997202cfb78000',1,'QXmppRtpPacket']]],
+  ['encoderformat',['encoderFormat',['../classQXmppRtpVideoChannel.html#ab3660ef26a4af0b91fbf199cf78e186b',1,'QXmppRtpVideoChannel']]],
   ['end',['end',['../classQXmppArchiveListIq.html#ab7dbb598303422e752b6c3a4e862a273',1,'QXmppArchiveListIq::end()'],['../classQXmppArchiveRemoveIq.html#adb6af974e8ec8891583644d3de6cf6ed',1,'QXmppArchiveRemoveIq::end()']]],
   ['error',['error',['../classQXmppStanza.html#a5ac3402fcc210cbc5a9a98501637bbc6',1,'QXmppStanza::error()'],['../classQXmppClient.html#a2bac100e40a909c860a3397643349937',1,'QXmppClient::error()'],['../classQXmppMucRoom.html#a0ff76d3091de98d7228e64ecaa954d42',1,'QXmppMucRoom::error()'],['../classQXmppOutgoingClient.html#a14d8a6c2a48c1ed6a2716002c0a29d21',1,'QXmppOutgoingClient::error()'],['../classQXmppTransferJob.html#a12fb2a7201244f6f506894f24b31f518',1,'QXmppTransferJob::error() const '],['../classQXmppTransferJob.html#a84198613e944168769b20357cfe2f626',1,'QXmppTransferJob::error()'],['../classQXmppPasswordReply.html#a08cd9a5b26a5281a2fea4f16a87aa0de',1,'QXmppPasswordReply::error()']]],
+  ['extendedaddresses',['extendedAddresses',['../classQXmppStanza.html#af2fb9de2e719e1312a33554b3866e0c6',1,'QXmppStanza']]],
   ['extensionname',['extensionName',['../classQXmppServerExtension.html#ae70b92e5a9f709ea25a3e54ec1bcbc5b',1,'QXmppServerExtension']]],
   ['extensionpriority',['extensionPriority',['../classQXmppServerExtension.html#a86c839fe03a4ec667878148eca0782f7',1,'QXmppServerExtension']]],
   ['extensions',['extensions',['../classQXmppStanza.html#a4742b3dc8dee132244107910ae8d1603',1,'QXmppStanza::extensions()'],['../classQXmppClient.html#aaa12f4be9ab48f0c9375479ecd7172e9',1,'QXmppClient::extensions()'],['../classQXmppServer.html#a51e1fb51eedb4f6ad645cfc4acc9926e',1,'QXmppServer::extensions()']]]
