@@ -12,9 +12,9 @@ var searchData=
   ['finish',['finish',['../classQXmppPasswordReply.html#ad009857528902d3696341b87079f0e26',1,'QXmppPasswordReply']]],
   ['finished',['finished',['../classQXmppCall.html#a4e2f8523540bcccc963e11401c666809',1,'QXmppCall::finished()'],['../classQXmppTransferJob.html#a602987d2e805440c93ef5b625a422856',1,'QXmppTransferJob::finished()'],['../classQXmppPasswordReply.html#a59f02853e4cf6feb747e219082b22374',1,'QXmppPasswordReply::finished()']]],
   ['finishlater',['finishLater',['../classQXmppPasswordReply.html#acc7e92729cf456e68b8e6341b97643bc',1,'QXmppPasswordReply']]],
+  ['first',['first',['../classQXmppResultSetReply.html#ae4b0426a63661fc66a10e895aa42fd4a',1,'QXmppResultSetReply']]],
   ['firstname',['firstName',['../classQXmppVCardIq.html#a64d99a338d3ebab31923aa6f4f30554b',1,'QXmppVCardIq']]],
-  ['form',['form',['../classQXmppMucOwnerIq.html#a1bdf7e3e90eee74765361825fe77e93f',1,'QXmppMucOwnerIq']]],
-  ['format',['format',['../classQXmppVideoDecoder.html#a58db97e0b759bbd216b6255e274bba47',1,'QXmppVideoDecoder']]],
+  ['form',['form',['../classQXmppMucOwnerIq.html#a1bdf7e3e90eee74765361825fe77e93f',1,'QXmppMucOwnerIq::form()'],['../classQXmppRegisterIq.html#a94966c6db427c9709ed86ad65ba87671',1,'QXmppRegisterIq::form()']]],
   ['foundation',['foundation',['../classQXmppJingleCandidate.html#a1454f64bd7d45a7a52a15486b49ee178',1,'QXmppJingleCandidate']]],
   ['from',['from',['../classQXmppStanza.html#a2e68644ae328ff374ffc5115597a525e',1,'QXmppStanza']]],
   ['fullname',['fullName',['../classQXmppVCardIq.html#ab654c884f23e9567e58ceb7ccc486b4e',1,'QXmppVCardIq']]]
