@@ -1,13 +1,11 @@
 var searchData=
 [
   ['handleelement',['handleElement',['../classQXmppServer.html#ab7ee638bc69fd4ca76638e45a64c6ec4',1,'QXmppServer']]],
-  ['handleframe',['handleFrame',['../classQXmppVideoEncoder.html#a8c7b14c4bbefcfab6916988033c1fad8',1,'QXmppVideoEncoder']]],
-  ['handlepacket',['handlePacket',['../classQXmppVideoDecoder.html#adc454869b3572ca8248996247e2da84f',1,'QXmppVideoDecoder']]],
   ['handlestanza',['handleStanza',['../classQXmppStream.html#aeb24cc2f3b30c902f0a6e3be9586510d',1,'QXmppStream::handleStanza()'],['../classQXmppClientExtension.html#af026d292204dc538249d16086e9e8108',1,'QXmppClientExtension::handleStanza()'],['../classQXmppServerExtension.html#ad8218187cd17b9d730fc72a9d722cf0a',1,'QXmppServerExtension::handleStanza()']]],
   ['handlestart',['handleStart',['../classQXmppStream.html#a970b0a6893c097c03ff6d279234178d5',1,'QXmppStream']]],
   ['handlestream',['handleStream',['../classQXmppStream.html#adda64f130a59719e241eea89b31c27fe',1,'QXmppStream']]],
   ['hangup',['hangup',['../classQXmppCall.html#a36e4892d706ae7035d5973f6e3b6a7cb',1,'QXmppCall']]],
   ['hasgetpassword',['hasGetPassword',['../classQXmppPasswordChecker.html#a41d37404a8a21397275164ed68e222bb',1,'QXmppPasswordChecker']]],
-  ['height',['height',['../classQXmppVideoFrame.html#aeed5d618b102be220ba2891f0f559e44',1,'QXmppVideoFrame']]],
+  ['height',['height',['../classQXmppDataForm_1_1Media.html#a6ce52e7ff7b5514f42f3b369e62d70f6',1,'QXmppDataForm::Media::height()'],['../classQXmppVideoFrame.html#aeed5d618b102be220ba2891f0f559e44',1,'QXmppVideoFrame::height()']]],
   ['host',['host',['../classQXmppJingleCandidate.html#a52ef0f40c4304cbaa96f76c89dffa0f2',1,'QXmppJingleCandidate::host()'],['../classQXmppConfiguration.html#a5109714e0bb5ad69f0e8dde063e54811',1,'QXmppConfiguration::host()']]]
 ];
