@@ -18,8 +18,7 @@ var searchData=
   ['localstreamkey',['localStreamKey',['../classQXmppOutgoingServer.html#a6f58821f193eb048cd1c4ff188c92925',1,'QXmppOutgoingServer']]],
   ['localuser',['localUser',['../classQXmppIceConnection.html#aa02512f5c19bfc6514b9bf20698943ad',1,'QXmppIceConnection']]],
   ['log',['log',['../classQXmppLogger.html#a2e5e503ecd4400477f47dec915ac4e89',1,'QXmppLogger']]],
-  ['logger',['logger',['../classQXmppServer.html#a289bef14c92ff46f8ceb5b12a904d8be',1,'QXmppServer']]],
-  ['loggerchanged',['loggerChanged',['../classQXmppClient.html#a74a8754f3e14945e597d964442281e70',1,'QXmppClient']]],
+  ['loggerchanged',['loggerChanged',['../classQXmppClient.html#a74a8754f3e14945e597d964442281e70',1,'QXmppClient::loggerChanged()'],['../classQXmppServer.html#af49a15f76003d1e3b2ff280f55e1ca54',1,'QXmppServer::loggerChanged()']]],
   ['logmessage',['logMessage',['../classQXmppLoggable.html#a403fa46ba15c65da706e8188d4312a05',1,'QXmppLoggable::logMessage()'],['../classQXmppRtpAudioChannel.html#a56e695ad1815f25c70dbef6b7310007b',1,'QXmppRtpAudioChannel::logMessage()']]],
   ['logreceived',['logReceived',['../classQXmppLoggable.html#afcb384597aa4cdee1dad7d2ec50871f4',1,'QXmppLoggable']]],
   ['logsent',['logSent',['../classQXmppLoggable.html#a50feb6fc691e90ba6b2e69c2a9aea794',1,'QXmppLoggable']]]
