@@ -10,6 +10,10 @@ var searchData=
   ['messages',['messages',['../classQXmppArchiveChat.html#ae70bdf32be4be0a9417a7c14c5ea6eea',1,'QXmppArchiveChat']]],
   ['method',['method',['../classQXmppRpcInvokeIq.html#a484c6cae06cfff75ba2247d16556c76f',1,'QXmppRpcInvokeIq']]],
   ['middlename',['middleName',['../classQXmppVCardIq.html#a52d8aa814dc5c90a9fa25fe852fad216',1,'QXmppVCardIq']]],
+  ['mucinvitationjid',['mucInvitationJid',['../classQXmppMessage.html#ac9ac6519101e7c5301c0656a7c7b1a40',1,'QXmppMessage']]],
+  ['mucinvitationpassword',['mucInvitationPassword',['../classQXmppMessage.html#abb1fa92382c83981f3ec2cbd2a2165ba',1,'QXmppMessage']]],
+  ['mucinvitationreason',['mucInvitationReason',['../classQXmppMessage.html#ab0ae8f1c7ef1082e90e80a1589a1c855',1,'QXmppMessage']]],
   ['mucitem',['mucItem',['../classQXmppPresence.html#abd4348359cb60bfe645086bec0681178',1,'QXmppPresence']]],
+  ['mucpassword',['mucPassword',['../classQXmppPresence.html#ae4d3eb2459c4536a14618662b3d10164',1,'QXmppPresence']]],
   ['mucstatuscodes',['mucStatusCodes',['../classQXmppPresence.html#afee1692914be90c24da5e872933e5023',1,'QXmppPresence']]]
 ];
