@@ -13,31 +13,35 @@ var searchData=
   ['qxmppconfiguration',['QXmppConfiguration',['../classQXmppConfiguration.html#acd68380ad2353139a8c29087c40e4dcc',1,'QXmppConfiguration::QXmppConfiguration()'],['../classQXmppConfiguration.html#ac91c247c5ee60472abb5393f9e32d0f2',1,'QXmppConfiguration::QXmppConfiguration(const QXmppConfiguration &amp;other)']]],
   ['qxmppdataform',['QXmppDataForm',['../classQXmppDataForm.html#a058f203f616dbffbd32043f509a9ff65',1,'QXmppDataForm::QXmppDataForm(QXmppDataForm::Type type=QXmppDataForm::None)'],['../classQXmppDataForm.html#a976fd7811d7f937fd2f9a7d313eb7ca8',1,'QXmppDataForm::QXmppDataForm(const QXmppDataForm &amp;other)']]],
   ['qxmppdialback',['QXmppDialback',['../classQXmppDialback.html#a1aa371e5859efa4eb5a5a733f609db3e',1,'QXmppDialback']]],
+  ['qxmppextendedaddress',['QXmppExtendedAddress',['../classQXmppExtendedAddress.html#a977ce245d062f5cb8398b02ecff76163',1,'QXmppExtendedAddress::QXmppExtendedAddress()'],['../classQXmppExtendedAddress.html#a2a88bb47091f713d6b8176ab2ee1101f',1,'QXmppExtendedAddress::QXmppExtendedAddress(const QXmppExtendedAddress &amp;)']]],
   ['qxmppicecomponent',['QXmppIceComponent',['../classQXmppIceComponent.html#ac42db14e22921cac54b2e7e2e9624c3d',1,'QXmppIceComponent']]],
   ['qxmppiceconnection',['QXmppIceConnection',['../classQXmppIceConnection.html#a7d406bc9a1991257db34c493bc5780a7',1,'QXmppIceConnection']]],
   ['qxmppincomingclient',['QXmppIncomingClient',['../classQXmppIncomingClient.html#a4544a58d3047af1fb4b997055fae9447',1,'QXmppIncomingClient']]],
   ['qxmppincomingserver',['QXmppIncomingServer',['../classQXmppIncomingServer.html#a35f13c6597f2c46fe220e7f9f612832c',1,'QXmppIncomingServer']]],
   ['qxmppinvokable',['QXmppInvokable',['../classQXmppInvokable.html#ae3f2b1d6d85b4ec6c7565554491ce6e3',1,'QXmppInvokable']]],
-  ['qxmppiq',['QXmppIq',['../classQXmppIq.html#a16db985e7cbf842dbca1cb94ec57c64f',1,'QXmppIq']]],
+  ['qxmppiq',['QXmppIq',['../classQXmppIq.html#a16db985e7cbf842dbca1cb94ec57c64f',1,'QXmppIq::QXmppIq(QXmppIq::Type type=QXmppIq::Get)'],['../classQXmppIq.html#a64c242ce6d42d7013d53120c58be5da2',1,'QXmppIq::QXmppIq(const QXmppIq &amp;other)']]],
   ['qxmppjingleiq',['QXmppJingleIq',['../classQXmppJingleIq.html#aeb7657fe2e9f6d5a9da2beef434625ff',1,'QXmppJingleIq']]],
   ['qxmpploggable',['QXmppLoggable',['../classQXmppLoggable.html#a05ad3142486bec62b2d58ad49b1d4005',1,'QXmppLoggable']]],
   ['qxmpplogger',['QXmppLogger',['../classQXmppLogger.html#a103f204a149f91d7e2c4faf7d02d2266',1,'QXmppLogger']]],
-  ['qxmppmessage',['QXmppMessage',['../classQXmppMessage.html#aa51870c00e3ffadc8555e00e0153c136',1,'QXmppMessage']]],
+  ['qxmppmessage',['QXmppMessage',['../classQXmppMessage.html#aa51870c00e3ffadc8555e00e0153c136',1,'QXmppMessage::QXmppMessage(const QString &amp;from=&quot;&quot;, const QString &amp;to=&quot;&quot;, const QString &amp;body=&quot;&quot;, const QString &amp;thread=&quot;&quot;)'],['../classQXmppMessage.html#af73b605ad48ee6ecc111975f774c6edd',1,'QXmppMessage::QXmppMessage(const QXmppMessage &amp;other)']]],
   ['qxmppmessagereceiptmanager',['QXmppMessageReceiptManager',['../classQXmppMessageReceiptManager.html#abd24b74a2784930429f1e9df1d7704fa',1,'QXmppMessageReceiptManager']]],
   ['qxmppmucmanager',['QXmppMucManager',['../classQXmppMucManager.html#a0eb8a3dbacfa9983e2ac72cd6a7629a3',1,'QXmppMucManager']]],
   ['qxmppoutgoingclient',['QXmppOutgoingClient',['../classQXmppOutgoingClient.html#a6713a94557a69df0051039b6f9a9cf3c',1,'QXmppOutgoingClient']]],
   ['qxmppoutgoingserver',['QXmppOutgoingServer',['../classQXmppOutgoingServer.html#a10e2b65e7bc9957db290b0a6de931bed',1,'QXmppOutgoingServer']]],
   ['qxmpppasswordreply',['QXmppPasswordReply',['../classQXmppPasswordReply.html#aee5c16b4954a41b183086f108df26971',1,'QXmppPasswordReply']]],
-  ['qxmpppresence',['QXmppPresence',['../classQXmppPresence.html#a55df3a12d8d19870aa2c80bf132778c2',1,'QXmppPresence']]],
+  ['qxmpppresence',['QXmppPresence',['../classQXmppPresence.html#ab3facb1c108a346c1866f11133592601',1,'QXmppPresence::QXmppPresence(QXmppPresence::Type type=QXmppPresence::Available)'],['../classQXmppPresence.html#a74ef4824a0c7c70c095c9e783a3b55b4',1,'QXmppPresence::QXmppPresence(const QXmppPresence &amp;other)']]],
   ['qxmpprostermanager',['QXmppRosterManager',['../classQXmppRosterManager.html#aa96bd124e15813b402bc1de93f9e4f7b',1,'QXmppRosterManager']]],
   ['qxmpprpcmanager',['QXmppRpcManager',['../classQXmppRpcManager.html#a8fece0110e91b17f2868575303d7c90f',1,'QXmppRpcManager']]],
   ['qxmpprtpaudiochannel',['QXmppRtpAudioChannel',['../classQXmppRtpAudioChannel.html#af8d0d31bd72cb5455de7dcfbe27bcf01',1,'QXmppRtpAudioChannel']]],
   ['qxmpprtpvideochannel',['QXmppRtpVideoChannel',['../classQXmppRtpVideoChannel.html#acd71a25b1c88bb225f7c88c5f6951f63',1,'QXmppRtpVideoChannel']]],
   ['qxmppserver',['QXmppServer',['../classQXmppServer.html#a1e63b89e62f124544a1052ca6eff2af5',1,'QXmppServer']]],
   ['qxmppsslserver',['QXmppSslServer',['../classQXmppSslServer.html#af0ef7762cca74cc5f833f0891348e08d',1,'QXmppSslServer']]],
-  ['qxmppstanza',['QXmppStanza',['../classQXmppStanza.html#aeda5073d2af6c52e78f127bca4306ace',1,'QXmppStanza']]],
+  ['qxmppstanza',['QXmppStanza',['../classQXmppStanza.html#aeda5073d2af6c52e78f127bca4306ace',1,'QXmppStanza::QXmppStanza(const QString &amp;from=QString(), const QString &amp;to=QString())'],['../classQXmppStanza.html#af8e4636d056c754347635ba26cd8d60c',1,'QXmppStanza::QXmppStanza(const QXmppStanza &amp;other)']]],
   ['qxmppstream',['QXmppStream',['../classQXmppStream.html#a70a8f8a0734c3a681fb0079890d99786',1,'QXmppStream']]],
   ['qxmpptransfermanager',['QXmppTransferManager',['../classQXmppTransferManager.html#aa88b03ffc2b9039a50bae7e79e759ed7',1,'QXmppTransferManager']]],
-  ['qxmppvcardiq',['QXmppVCardIq',['../classQXmppVCardIq.html#a93c39e3c608a259c505ba0ecd841e0db',1,'QXmppVCardIq']]],
+  ['qxmppvcardaddress',['QXmppVCardAddress',['../classQXmppVCardAddress.html#ab31c2eab8fb090d6716515cfe0fad36b',1,'QXmppVCardAddress::QXmppVCardAddress()'],['../classQXmppVCardAddress.html#a2093d0ed8737c0f04ffa543c3943f0a9',1,'QXmppVCardAddress::QXmppVCardAddress(const QXmppVCardAddress &amp;other)']]],
+  ['qxmppvcardemail',['QXmppVCardEmail',['../classQXmppVCardEmail.html#ac2d3a7f08975a9d6a395c8ed60d1a4ef',1,'QXmppVCardEmail::QXmppVCardEmail()'],['../classQXmppVCardEmail.html#a769b18f711a4bca0a6de8f7707e89a0b',1,'QXmppVCardEmail::QXmppVCardEmail(const QXmppVCardEmail &amp;other)']]],
+  ['qxmppvcardiq',['QXmppVCardIq',['../classQXmppVCardIq.html#a93c39e3c608a259c505ba0ecd841e0db',1,'QXmppVCardIq::QXmppVCardIq(const QString &amp;bareJid=&quot;&quot;)'],['../classQXmppVCardIq.html#a7e09646833b005171d2f3564cb446e91',1,'QXmppVCardIq::QXmppVCardIq(const QXmppVCardIq &amp;other)']]],
+  ['qxmppvcardphone',['QXmppVCardPhone',['../classQXmppVCardPhone.html#ab8227e376f5aba012a8e05d6f09c7c6a',1,'QXmppVCardPhone::QXmppVCardPhone()'],['../classQXmppVCardPhone.html#acd06e5045a4f27ce29a0bf34b6d4653c',1,'QXmppVCardPhone::QXmppVCardPhone(const QXmppVCardPhone &amp;other)']]],
   ['qxmppvideoframe',['QXmppVideoFrame',['../classQXmppVideoFrame.html#ae33d6c7b73381921c6f6b70fa2b16cf9',1,'QXmppVideoFrame::QXmppVideoFrame()'],['../classQXmppVideoFrame.html#aa8af160798b29f2164e93b2f84b3de8e',1,'QXmppVideoFrame::QXmppVideoFrame(int bytes, const QSize &amp;size, int bytesPerLine, PixelFormat format)']]]
 ];
