@@ -3,7 +3,8 @@ var searchData=
   ['readframes',['readFrames',['../classQXmppRtpVideoChannel.html#a2d2c5854406f34fedbd10d6096428493',1,'QXmppRtpVideoChannel']]],
   ['reason',['reason',['../classQXmppJingleIq.html#a0109cfd1525f9ee69a40ae0ce3962d69',1,'QXmppJingleIq::reason()'],['../classQXmppJingleIq.html#a9027b28bc5f929ee415f0de50563cac7',1,'QXmppJingleIq::reason() const '],['../classQXmppMucItem.html#a7b5574030b7bb253c23ccf46fffde87e',1,'QXmppMucItem::reason()']]],
   ['receiptid',['receiptId',['../classQXmppMessage.html#a3df33f75c06de9a3fbe3897ca89893db',1,'QXmppMessage']]],
-  ['refusesubscription',['refuseSubscription',['../classQXmppRosterManager.html#a8942d10cdcdad0821f4ce75fe0ee583d',1,'QXmppRosterManager']]],
+  ['refusesubscription',['refuseSubscription',['../classQXmppRosterManager.html#a9e9ffd157b981d1fb4a3b641de2890c7',1,'QXmppRosterManager']]],
+  ['region',['region',['../classQXmppVCardAddress.html#a02bd9c333ef0d1d3eac3853bb8391849',1,'QXmppVCardAddress']]],
   ['remotedomain',['remoteDomain',['../classQXmppOutgoingServer.html#acf167e9cf078b1ee9ef80fd2d3ac0b83',1,'QXmppOutgoingServer']]],
   ['removecollections',['removeCollections',['../classQXmppArchiveManager.html#a3de27735449b3fb10a1e85032ed3e0b6',1,'QXmppArchiveManager']]],
   ['removeextension',['removeExtension',['../classQXmppClient.html#ae48477dc92abd66193789bfc60d16d62',1,'QXmppClient']]],
@@ -21,7 +22,9 @@ var searchData=
   ['reserveports',['reservePorts',['../classQXmppIceComponent.html#a1fc342ff0fa196320b86a2c1413b33fc',1,'QXmppIceComponent']]],
   ['resource',['resource',['../classQXmppBindIq.html#ac6aa0a84579d18f28196301a774a6e42',1,'QXmppBindIq::resource()'],['../classQXmppConfiguration.html#ad6969bdce483c31e1196ffb0cca800f3',1,'QXmppConfiguration::resource()']]],
   ['responder',['responder',['../classQXmppJingleIq.html#ad77bd95c596dbef85b9d84ff72fb4716',1,'QXmppJingleIq']]],
-  ['retrievecollection',['retrieveCollection',['../classQXmppArchiveManager.html#a079d1795b51ab24e00a7b10a6a0bba15',1,'QXmppArchiveManager']]],
+  ['resultsetquery',['resultSetQuery',['../classQXmppArchiveListIq.html#aed31e99a9387ef300bf91564f83f2e84',1,'QXmppArchiveListIq::resultSetQuery()'],['../classQXmppArchiveRetrieveIq.html#a927c46455efcff2fb9221f9246fcf629',1,'QXmppArchiveRetrieveIq::resultSetQuery()']]],
+  ['resultsetreply',['resultSetReply',['../classQXmppArchiveChatIq.html#a63d9405b2b4c4b0573905a2e52a95c96',1,'QXmppArchiveChatIq::resultSetReply()'],['../classQXmppArchiveListIq.html#a47bb290958acb0721b35bb51161fa1da',1,'QXmppArchiveListIq::resultSetReply()']]],
+  ['retrievecollection',['retrieveCollection',['../classQXmppArchiveManager.html#a5a8584a4dfb0c2fa8bb0e85690c269f9',1,'QXmppArchiveManager::retrieveCollection(const QString &amp;jid, const QDateTime &amp;start, const QXmppResultSetQuery &amp;rsm=QXmppResultSetQuery())'],['../classQXmppArchiveManager.html#a7967bec8510af778f581d3232193895f',1,'QXmppArchiveManager::retrieveCollection(const QString &amp;jid, const QDateTime &amp;start, int max)']]],
   ['ringing',['ringing',['../classQXmppJingleIq.html#a2cc94c4e2e8dec892d8388aca47b0268',1,'QXmppJingleIq::ringing()'],['../classQXmppCall.html#ac661611e7d0bf5ebcdf56a28d60a95aa',1,'QXmppCall::ringing()']]],
   ['role',['role',['../classQXmppMucItem.html#af65444d3b29bbb8d78b4d25aa8f02894',1,'QXmppMucItem']]],
   ['roomadded',['roomAdded',['../classQXmppMucManager.html#a948446ebb49b07e772d8a70a0b8e71e6',1,'QXmppMucManager']]],
