@@ -2,6 +2,6 @@ var searchData=
 [
   ['localfileurl',['localFileUrl',['../classQXmppTransferJob.html#aba043a492dc36a027323afd921c1fa29',1,'QXmppTransferJob']]],
   ['logfilepath',['logFilePath',['../classQXmppLogger.html#a1be30b0f1390d14cb6d8535d4898a703',1,'QXmppLogger']]],
-  ['logger',['logger',['../classQXmppClient.html#ae5fca0867efe7e7fcae90cbbf10b8193',1,'QXmppClient']]],
+  ['logger',['logger',['../classQXmppClient.html#ae5fca0867efe7e7fcae90cbbf10b8193',1,'QXmppClient::logger()'],['../classQXmppServer.html#a0fa9d97d5be1f6429b35154c7621bd24',1,'QXmppServer::logger()']]],
   ['loggingtype',['loggingType',['../classQXmppLogger.html#a896f3347ee0c517db3404e07c6853187',1,'QXmppLogger']]]
 ];
