@@ -55,6 +55,9 @@ mainDialog::mainDialog(QWidget *parent): QDialog(parent, Qt::Window),
     m_signOutAction("Sign out", this),
     m_settingsMenu(0)
 {
+    bool check;
+    Q_UNUSED(check);
+
     ui->setupUi(this);
     createTrayIconAndMenu();
     createSettingsMenu();
@@ -65,7 +68,7 @@ mainDialog::mainDialog(QWidget *parent): QDialog(parent, Qt::Window),
     showSignInPage();
     loadAccounts();
 
-    bool check = connect(ui->lineEdit_userName->completer(),
+    check = connect(ui->lineEdit_userName->completer(),
                          SIGNAL(activated(QString)),
                          this, SLOT(userNameCompleter_activated(QString)));
     Q_ASSERT(check);
@@ -76,7 +79,7 @@ mainDialog::mainDialog(QWidget *parent): QDialog(parent, Qt::Window),
     Q_ASSERT(check);
 
     check = connect(&m_xmppClient.rosterManager(),
-                         SIGNAL(rosterChanged(QString)),
+                         SIGNAL(itemChanged(QString)),
                          this, SLOT(rosterChanged(QString)));
     Q_ASSERT(check);
 
@@ -141,8 +144,8 @@ mainDialog::mainDialog(QWidget *parent): QDialog(parent, Qt::Window),
                     SLOT(presenceTypeChanged(QXmppPresence::Type)));
     Q_ASSERT(check);
     check = connect(&m_statusWidget,
-                    SIGNAL(presenceStatusTypeChanged(QXmppPresence::Status::Type)),
-                    SLOT(presenceStatusTypeChanged(QXmppPresence::Status::Type)));
+                    SIGNAL(presenceStatusTypeChanged(QXmppPresence::AvailableStatusType)),
+                    SLOT(presenceStatusTypeChanged(QXmppPresence::AvailableStatusType)));
     Q_ASSERT(check);
     check = connect(&m_statusWidget,
                     SIGNAL(avatarChanged(QImage)),
@@ -355,15 +358,20 @@ void mainDialog::showChatDialog(const QString& bareJid)
 
 void mainDialog::messageReceived(const QXmppMessage& msg)
 {
-    QString from = msg.from();
-    getChatDialog(QXmppUtils::jidToBareJid(from))->show();
-    getChatDialog(QXmppUtils::jidToBareJid(from))->messageReceived(msg.body());
+    if (msg.body().isEmpty())
+        return;
+
+    chatDialog *dialog = getChatDialog(QXmppUtils::jidToBareJid(msg.from()));
+    if (dialog) {
+        dialog->show();
+        dialog->messageReceived(msg.body());
+    }
 }
 
 void mainDialog::statusTextChanged(const QString& status)
 {
     QXmppPresence presence = m_xmppClient.clientPresence();
-    presence.status().setStatusText(status);
+    presence.setStatusText(status);
     addPhotoHash(presence);
     m_xmppClient.setClientPresence(presence);
 }
@@ -378,7 +386,7 @@ void mainDialog::presenceTypeChanged(QXmppPresence::Type presenceType)
     {
         QXmppPresence newPresence = m_xmppClient.clientPresence();
         newPresence.setType(presenceType);
-        newPresence.status().setType(QXmppPresence::Status::Online);
+        newPresence.setAvailableStatusType(QXmppPresence::Online);
         addPhotoHash(newPresence);
         m_xmppClient.setClientPresence(newPresence);
     }
@@ -386,14 +394,11 @@ void mainDialog::presenceTypeChanged(QXmppPresence::Type presenceType)
             presenceToStatusText(m_xmppClient.clientPresence()));
 }
 
-void mainDialog::presenceStatusTypeChanged(QXmppPresence::Status::Type statusType)
+void mainDialog::presenceStatusTypeChanged(QXmppPresence::AvailableStatusType statusType)
 {
     QXmppPresence presence = m_xmppClient.clientPresence();
-    if(statusType == QXmppPresence::Status::Offline)
-        presence.setType(QXmppPresence::Unavailable);
-    else
-        presence.setType(QXmppPresence::Available);
-    presence.status().setType(statusType);
+    presence.setType(QXmppPresence::Available);
+    presence.setAvailableStatusType(statusType);
     addPhotoHash(presence);
     m_xmppClient.setClientPresence(presence);
     m_statusWidget.setStatusText(
@@ -426,13 +431,16 @@ void mainDialog::avatarChanged(const QImage& image)
 
 void mainDialog::updateStatusWidget()
 {
-    // fetch selfVCard
-    m_xmppClient.vCardManager().requestVCard();
+    const QString bareJid = m_xmppClient.configuration().jidBare();
 
-    m_statusWidget.setDisplayName(m_xmppClient.configuration().jidBare());
+    // initialise status widget
+    updateVCard(bareJid);
     m_statusWidget.setStatusText(presenceToStatusText(m_xmppClient.clientPresence()));
     m_statusWidget.setPresenceAndStatusType(m_xmppClient.clientPresence().type(),
-                                            m_xmppClient.clientPresence().status().type());
+                                            m_xmppClient.clientPresence().availableStatusType());
+
+    // fetch own vCard
+    m_vCardCache.requestVCard(bareJid);
 }
 
 void mainDialog::signIn()
@@ -521,23 +529,25 @@ void mainDialog::showLoginStatusWithCounter(const QString& msg, int time)
 
 void mainDialog::updateVCard(const QString& bareJid)
 {
-    if(bareJid != m_xmppClient.configuration().jidBare())
-    {
-        m_rosterItemModel.updateAvatar(bareJid,
-                                   m_vCardCache.getAvatar(bareJid));
-        m_rosterItemModel.updateName(bareJid, m_vCardCache.getVCard(bareJid).fullName());
-    }
-    else
-    {
-        QXmppVCardIq& vCard = m_vCardCache.getVCard(m_xmppClient.configuration().jidBare());
-        QString fullName = vCard.fullName();
+    // determine full name
+    const QXmppVCardIq vCard = m_vCardCache.getVCard(bareJid);
+    QString fullName = vCard.fullName();
+    if (fullName.isEmpty())
+        fullName = bareJid;
 
-        if(fullName.isEmpty())
-            fullName = m_xmppClient.configuration().jidBare();
+    // determine avatar
+    QImage avatar = m_vCardCache.getAvatar(bareJid);
+    if (avatar.isNull())
+        avatar = QImage(":/icons/resource/avatar.png");
 
+    if (bareJid == m_xmppClient.configuration().jidBare()) {
+        // update our own information
+        m_statusWidget.setAvatar(avatar);
         m_statusWidget.setDisplayName(fullName);
-
-        m_statusWidget.setAvatar(m_vCardCache.getAvatar(bareJid));
+    } else {
+        // update roster information
+        m_rosterItemModel.updateAvatar(bareJid, avatar);
+        m_rosterItemModel.updateName(bareJid, fullName);
     }
 }
 
@@ -614,7 +624,10 @@ void mainDialog::action_quit()
 
 void mainDialog::createTrayIconAndMenu()
 {
-    bool check = connect(&m_quitAction, SIGNAL(triggered()), SLOT(action_quit()));
+    bool check;
+    Q_UNUSED(check);
+
+    check = connect(&m_quitAction, SIGNAL(triggered()), SLOT(action_quit()));
     Q_ASSERT(check);
 
     check = connect(&m_signOutAction, SIGNAL(triggered()), SLOT(action_signOut()));
@@ -625,7 +638,7 @@ void mainDialog::createTrayIconAndMenu()
 
     check = connect(&m_trayIcon, SIGNAL(activated(QSystemTrayIcon::ActivationReason)),
                     SLOT(action_trayIconActivated(QSystemTrayIcon::ActivationReason)));
-        Q_ASSERT(check);
+    Q_ASSERT(check);
 
     m_trayIconMenu.addAction(&m_signOutAction);
     m_trayIconMenu.addSeparator();
