@@ -25,10 +25,12 @@
 #include "rosterItem.h"
 #include <QImage>
 
-rosterItem::rosterItem(const QString& bareJid) //: QStandardItem(bareJid)
+rosterItem::rosterItem(const QString& bareJid)
 {
-    setStatusType(QXmppPresence::Status::Offline);
-    setStatusText("Offline");
+    setData(bareJid, rosterItem::BareJid);
+    setData("Offline", rosterItem::StatusText);
+    setAvatar(QImage(":/icons/resource/avatar.png"));
+    setIcon(QIcon(":/icons/resource/gray.png"));
 }
 
 void rosterItem::setName(const QString& name)
@@ -41,85 +43,49 @@ QString rosterItem::getName()
     return text();
 }
 
-void rosterItem::setBareJid(const QString& bareJid)
+void rosterItem::setPresence(const QXmppPresence &presence)
 {
-    setData(bareJid, rosterItem::BareJid);
-}
-
-void rosterItem::setStatusText(const QString& text)
-{
-    setData(text, rosterItem::StatusText);
-}
-
-QString rosterItem::getBareJid()
-{
-    return data(rosterItem::BareJid).toString();
-}
-
-QString rosterItem::getStatusText()
-{
-    return data(rosterItem::StatusText).toString();
-}
-
-void rosterItem::setStatusType(QXmppPresence::Status::Type type)
-{
-    setData(static_cast<int>(type), StatusType);
-    QString icon;
-    switch(type)
-    {
-    case QXmppPresence::Status::Online:
-    case QXmppPresence::Status::Chat:
-        icon = "green";
-        break;
-    case QXmppPresence::Status::Away:
-    case QXmppPresence::Status::XA:
-        icon = "orange";
-        break;
-    case QXmppPresence::Status::DND:
-        icon = "red";
-        break;
-    //case QXmppPresence::Status::Invisible:
-    case QXmppPresence::Status::Offline:
-        icon = "gray";
-        break;
+    // determine status text
+    QString statusText = presence.statusText();
+    if (statusText.isEmpty()) {
+        if(presence.type() == QXmppPresence::Available)
+            statusText = "Available";
+        else if(presence.type() == QXmppPresence::Unavailable)
+            statusText = "Offline";
     }
-    if(!icon.isEmpty())
-        setIcon(QIcon(":/icons/resource/"+icon+".png"));
-}
 
-QXmppPresence::Status::Type rosterItem::getStatusType()
-{
-    return static_cast<QXmppPresence::Status::Type>(data(StatusType).toInt());
-}
+    // store data
+    setData(statusText, rosterItem::StatusText);
+    setData(static_cast<int>(presence.type()), PresenceType);
+    setData(static_cast<int>(presence.availableStatusType()), StatusType);
 
-void rosterItem::setPresenceType(QXmppPresence::Type type)
-{
-    setData(static_cast<int>(type), PresenceType);
+    // update icon
     QString icon;
-    switch(type)
-    {
-    case QXmppPresence::Available:
-        break;
-    case QXmppPresence::Unavailable:
+    if (presence.type() == QXmppPresence::Available) {
+        switch (presence.availableStatusType())
+        {
+        case QXmppPresence::Online:
+        case QXmppPresence::Chat:
+            icon = "green";
+            break;
+        case QXmppPresence::Away:
+        case QXmppPresence::XA:
+            icon = "orange";
+            break;
+        case QXmppPresence::DND:
+            icon = "red";
+            break;
+        case QXmppPresence::Invisible:
+            icon = "gray";
+            break;
+        }
+    } else {
         icon = "gray";
-        break;
-    case QXmppPresence::Error:
-    case QXmppPresence::Subscribe:
-    case QXmppPresence::Subscribed:
-    case QXmppPresence::Unsubscribe:
-    case QXmppPresence::Unsubscribed:
-    case QXmppPresence::Probe:
-        break;
     }
-    if(!icon.isEmpty())
+    if (!icon.isEmpty())
         setIcon(QIcon(":/icons/resource/"+icon+".png"));
 }
 
-QXmppPresence::Type rosterItem::getPresenceType()
-{
-    return static_cast<QXmppPresence::Type>(data(PresenceType).toInt());
-}
-
 void rosterItem::setAvatar(const QImage& image)
 {
     setData(QVariant(image), rosterItem::Avatar);
@@ -136,6 +102,8 @@ rosterItemDelegate::rosterItemDelegate()
 
 QSize rosterItemDelegate::sizeHint(const QStyleOptionViewItem& option, const QModelIndex & index) const
 {
+    Q_UNUSED(option);
+    Q_UNUSED(index);
     return QSize(44, 36);
 }
 
