@@ -28,9 +28,6 @@
 
 #include <QHostAddress>
 
-class QDomElement;
-class QXmlStreamWriter;
-
 class QXMPP_EXPORT QXmppByteStreamIq : public QXmppIq
 {
 public:
@@ -46,8 +43,8 @@ public:
         QString jid() const;
         void setJid(const QString &jid);
 
-        QHostAddress host() const;
-        void setHost(const QHostAddress &host);
+        QString host() const;
+        void setHost(const QString &host);
 
         quint16 port() const;
         void setPort(quint16 port);
@@ -56,7 +53,7 @@ public:
         void setZeroconf(const QString &zeroconf);
 
     private:
-        QHostAddress m_host;
+        QString m_host;
         QString m_jid;
         quint16 m_port;
         QString m_zeroconf;
