@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2011 The QXmpp developers
+ * Copyright (C) 2008-2012 The QXmpp developers
  *
  * Author:
  *  Jeremy Lainé
@@ -27,7 +27,7 @@
 #include <QMetaType>
 #include <QTimer>
 
-#include "QXmppCodec.h"
+#include "QXmppCodec_p.h"
 #include "QXmppJingleIq.h"
 #include "QXmppRtpChannel.h"
 
@@ -167,10 +167,6 @@ void QXmppRtpChannel::setRemotePayloadTypes(const QList<QXmppJinglePayloadType>
     payloadTypesChanged();
 }
 
-void QXmppRtpChannel::payloadTypesChanged()
-{
-}
-
 enum CodecId {
     G711u = 0,
     GSM = 3,
@@ -367,15 +363,13 @@ QXmppRtpAudioChannel::~QXmppRtpAudioChannel()
 }
 
 /// Returns the number of bytes that are available for reading.
-///
 
 qint64 QXmppRtpAudioChannel::bytesAvailable() const
 {
     return QIODevice::bytesAvailable() + d->incomingBuffer.size();
 }
 
-/// Closes the RTP channel.
-///
+/// Closes the RTP audio channel.
 
 void QXmppRtpAudioChannel::close()
 {
@@ -495,6 +489,17 @@ QIODevice::OpenMode QXmppRtpAudioChannel::openMode() const
     return QIODevice::openMode();
 }
 
+/// Returns the RTP channel's payload type.
+///
+/// You can use this to determine the QAudioFormat to use with your
+/// QAudioInput/QAudioOutput.
+
+QXmppJinglePayloadType QXmppRtpAudioChannel::payloadType() const
+{
+    return d->payloadType;
+}
+
+/// \cond
 qint64 QXmppRtpAudioChannel::readData(char * data, qint64 maxSize)
 {
     // if we are filling the buffer, return empty samples
@@ -533,16 +538,6 @@ qint64 QXmppRtpAudioChannel::readData(char * data, qint64 maxSize)
     return maxSize;
 }
 
-/// Returns the RTP channel's payload type.
-///
-/// You can use this to determine the QAudioFormat to use with your
-/// QAudioInput/QAudioOutput.
-
-QXmppJinglePayloadType QXmppRtpAudioChannel::payloadType() const
-{
-    return d->payloadType;
-}
-
 void QXmppRtpAudioChannel::payloadTypesChanged()
 {
     // delete incoming codecs
@@ -580,6 +575,7 @@ void QXmppRtpAudioChannel::payloadTypesChanged()
 
     open(QIODevice::ReadWrite | QIODevice::Unbuffered);
 }
+/// \endcond
 
 /// Returns the position in the received audio data.
 
@@ -634,6 +630,7 @@ void QXmppRtpAudioChannel::stopTone(QXmppRtpAudioChannel::Tone tone)
     }
 }
 
+/// \cond
 qint64 QXmppRtpAudioChannel::writeData(const char * data, qint64 maxSize)
 {
     if (!d->outgoingCodec) {
@@ -649,6 +646,7 @@ qint64 QXmppRtpAudioChannel::writeData(const char * data, qint64 maxSize)
 
     return maxSize;
 }
+/// \endcond
 
 void QXmppRtpAudioChannel::writeDatagram()
 {
@@ -906,8 +904,7 @@ QXmppRtpVideoChannel::~QXmppRtpVideoChannel()
     delete d;
 }
 
-/// Closes the RTP channel.
-///
+/// Closes the RTP video channel.
 
 void QXmppRtpVideoChannel::close()
 {
@@ -934,6 +931,8 @@ void QXmppRtpVideoChannel::datagramReceived(const QByteArray &ba)
     d->frames << decoder->handlePacket(packet);
 }
 
+/// Returns the video format used by the encoder.
+
 QXmppVideoFormat QXmppRtpVideoChannel::decoderFormat() const
 {
     if (d->decoders.isEmpty())
@@ -942,11 +941,15 @@ QXmppVideoFormat QXmppRtpVideoChannel::decoderFormat() const
     return d->decoders.value(key)->format();
 }
 
+/// Returns the video format used by the encoder.
+
 QXmppVideoFormat QXmppRtpVideoChannel::encoderFormat() const
 {
     return d->outgoingFormat;
 }
 
+/// Sets the video format used by the encoder.
+
 void QXmppRtpVideoChannel::setEncoderFormat(const QXmppVideoFormat &format)
 {
     if (d->encoder && !d->encoder->setFormat(format))
@@ -966,6 +969,7 @@ QIODevice::OpenMode QXmppRtpVideoChannel::openMode() const
     return mode;
 }
 
+/// \cond
 void QXmppRtpVideoChannel::payloadTypesChanged()
 {
     // refresh decoders
@@ -1016,6 +1020,7 @@ void QXmppRtpVideoChannel::payloadTypesChanged()
         }
     }
 }
+/// \endcond
 
 /// Decodes buffered RTP packets and returns a list of video frames.
 
