@@ -102,9 +102,9 @@ static bool parseHostAndPort(const QByteArray buffer, quint8 &type, QByteArray &
     return true;
 }
 
-QXmppSocksClient::QXmppSocksClient(const QHostAddress &proxyAddress, quint16 proxyPort, QObject *parent)
+QXmppSocksClient::QXmppSocksClient(const QString &proxyHost, quint16 proxyPort, QObject *parent)
     : QTcpSocket(parent),
-    m_proxyAddress(proxyAddress),
+    m_proxyHost(proxyHost),
     m_proxyPort(proxyPort),
     m_step(ConnectState)
 {
@@ -116,7 +116,7 @@ void QXmppSocksClient::connectToHost(const QString &hostName, quint16 hostPort)
 {
     m_hostName = hostName;
     m_hostPort = hostPort;
-    QTcpSocket::connectToHost(m_proxyAddress, m_proxyPort);
+    QTcpSocket::connectToHost(m_proxyHost, m_proxyPort);
 }
 
 void QXmppSocksClient::slotConnected()
@@ -157,7 +157,7 @@ void QXmppSocksClient::slotReadyRead()
         buffer[2] = 0x00; // reserved
         buffer.append(encodeHostAndPort(
             DomainName,
-            m_hostName.toAscii(),
+            m_hostName.toLatin1(),
             m_hostPort));
         write(buffer);
 
@@ -201,26 +201,25 @@ QXmppSocksServer::QXmppSocksServer(QObject *parent)
 {
     m_server = new QTcpServer(this);
     connect(m_server, SIGNAL(newConnection()), this, SLOT(slotNewConnection()));
+
+    m_server_v6 = new QTcpServer(this);
+    connect(m_server_v6, SIGNAL(newConnection()), this, SLOT(slotNewConnection()));
 }
 
 void QXmppSocksServer::close()
 {
     m_server->close();
+    m_server_v6->close();
 }
 
-bool QXmppSocksServer::listen(const QHostAddress &address, quint16 port)
+bool QXmppSocksServer::listen(quint16 port)
 {
-    return m_server->listen(address, port);
-}
+    if (!m_server->listen(QHostAddress::Any, port))
+        return false;
 
-bool QXmppSocksServer::isListening() const
-{
-    return m_server->isListening();
-}
-
-QHostAddress QXmppSocksServer::serverAddress() const
-{
-    return m_server->serverAddress();
+    // FIXME: this fails on Linux if /proc/sys/net/ipv6/bindv6only is 0
+    m_server_v6->listen(QHostAddress::AnyIPv6, m_server->serverPort());
+    return true;
 }
 
 quint16 QXmppSocksServer::serverPort() const
@@ -230,7 +229,11 @@ quint16 QXmppSocksServer::serverPort() const
 
 void QXmppSocksServer::slotNewConnection()
 {
-    QTcpSocket *socket = m_server->nextPendingConnection();
+    QTcpServer *server = qobject_cast<QTcpServer*>(sender());
+    if (!server)
+        return;
+
+    QTcpSocket *socket = server->nextPendingConnection();
     if (!socket)
         return;
 
