@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2011 The QXmpp developers
+ * Copyright (C) 2008-2012 The QXmpp developers
  *
  * Authors:
  *  Manjeet Dahiya
@@ -69,7 +69,7 @@ QXmppStream::QXmppStream(QObject *parent)
     // Make sure the random number generator is seeded
     if (!randomSeeded)
     {
-        qsrand(QTime(0,0,0).secsTo(QTime::currentTime()));
+        qsrand(QTime(0,0,0).msecsTo(QTime::currentTime()) ^ reinterpret_cast<quintptr>(this));
         randomSeeded = true;
     }
 }
@@ -166,10 +166,6 @@ void QXmppStream::setSocket(QSslSocket *socket)
                     this, SLOT(_q_socketConnected()));
     Q_ASSERT(check);
 
-    check = connect(socket, SIGNAL(disconnected()),
-                    this, SLOT(_q_socketDisconnected()));
-    Q_ASSERT(check);
-
     check = connect(socket, SIGNAL(encrypted()),
                     this, SLOT(_q_socketEncrypted()));
     Q_ASSERT(check);
@@ -180,11 +176,6 @@ void QXmppStream::setSocket(QSslSocket *socket)
     check = connect(socket, SIGNAL(readyRead()),
                     this, SLOT(_q_socketReadyRead()));
     Q_ASSERT(check);
-
-    // relay signals
-    check = connect(socket, SIGNAL(disconnected()),
-                    this, SIGNAL(disconnected()));
-    Q_ASSERT(check);
 }
 
 void QXmppStream::_q_socketConnected()
@@ -195,11 +186,6 @@ void QXmppStream::_q_socketConnected()
     handleStart();
 }
 
-void QXmppStream::_q_socketDisconnected()
-{
-    info("Socket disconnected");
-}
-
 void QXmppStream::_q_socketEncrypted()
 {
     debug("Socket encrypted");
