@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2011 The QXmpp developers
+ * Copyright (C) 2008-2012 The QXmpp developers
  *
  * Author:
  *  Jeremy Lainé
@@ -27,6 +27,7 @@
 #include <QDateTime>
 
 #include "QXmppClientExtension.h"
+#include "QXmppResultSet.h"
 
 class QXmppArchiveChat;
 class QXmppArchiveChatIq;
@@ -54,22 +55,26 @@ class QXMPP_EXPORT QXmppArchiveManager : public QXmppClientExtension
     Q_OBJECT
 
 public:
-    void listCollections(const QString &jid, const QDateTime &start = QDateTime(), const QDateTime &end = QDateTime(), int max = 0);
+    void listCollections(const QString &jid, const QDateTime &start = QDateTime(), const QDateTime &end = QDateTime(),
+                         const QXmppResultSetQuery &rsm = QXmppResultSetQuery());
+    void listCollections(const QString &jid, const QDateTime &start, const QDateTime &end, int max);
     void removeCollections(const QString &jid, const QDateTime &start = QDateTime(), const QDateTime &end = QDateTime());
-    void retrieveCollection(const QString &jid, const QDateTime &start, int max = 0);
+    void retrieveCollection(const QString &jid, const QDateTime &start, const QXmppResultSetQuery &rsm = QXmppResultSetQuery());
+    void retrieveCollection(const QString &jid, const QDateTime &start, int max);
 
     /// \cond
+    QStringList discoveryFeatures() const;
     bool handleStanza(const QDomElement &element);
     /// \endcond
 
 signals:
     /// This signal is emitted when archive list is received
     /// after calling listCollections()
-    void archiveListReceived(const QList<QXmppArchiveChat>&);
+    void archiveListReceived(const QList<QXmppArchiveChat>&, const QXmppResultSetReply &rsm = QXmppResultSetReply());
 
     /// This signal is emitted when archive chat is received
     /// after calling retrieveCollection()
-    void archiveChatReceived(const QXmppArchiveChat&);
+    void archiveChatReceived(const QXmppArchiveChat&, const QXmppResultSetReply &rsm = QXmppResultSetReply());
 };
 
 #endif
