@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2011 The QXmpp developers
+ * Copyright (C) 2008-2012 The QXmpp developers
  *
  * Author:
  *  Manjeet Dahiya
@@ -43,6 +43,12 @@ public:
     QString facebookAccessToken;
     QString facebookAppId;
 
+    // Google
+    QString googleAccessToken;
+
+    // Windows Live
+    QString windowsLiveAccessToken;
+
     // default is false
     bool autoAcceptSubscriptions;
     // default is true
@@ -55,16 +61,15 @@ public:
     int keepAliveTimeout;
     // will keep reconnecting if disconnected, default is true
     bool autoReconnectionEnabled;
-    bool useSASLAuthentication; ///< flag to specify what authentication system
-                                  ///< to be used
-                                ///< defualt is true and use SASL
-                                ///< false would use NonSASL if available
+    // which authentication systems to use (if any)
+    bool useSASLAuthentication;
+    bool useNonSASLAuthentication;
     // default is true
     bool ignoreSslErrors;
 
     QXmppConfiguration::StreamSecurityMode streamSecurityMode;
     QXmppConfiguration::NonSASLAuthMechanism nonSASLAuthMechanism;
-    QXmppConfiguration::SASLAuthMechanism SASLAuthMechanism;
+    QString saslAuthMechanism;
 
     QNetworkProxy networkProxy;
 
@@ -81,10 +86,11 @@ QXmppConfigurationPrivate::QXmppConfigurationPrivate()
     , keepAliveTimeout(20)
     , autoReconnectionEnabled(true)
     , useSASLAuthentication(true)
+    , useNonSASLAuthentication(true)
     , ignoreSslErrors(true)
     , streamSecurityMode(QXmppConfiguration::TLSEnabled)
     , nonSASLAuthMechanism(QXmppConfiguration::NonSASLDigest)
-    , SASLAuthMechanism(QXmppConfiguration::SASLDigestMD5)
+    , saslAuthMechanism("DIGEST-MD5")
 {
 }
 
@@ -328,6 +334,44 @@ void QXmppConfiguration::setFacebookAppId(const QString& appId)
     d->facebookAppId = appId;
 }
 
+/// Returns the access token used for X-OAUTH2 authentication.
+
+QString QXmppConfiguration::googleAccessToken() const
+{
+    return d->googleAccessToken;
+}
+
+/// Sets the access token used for X-OAUTH2 authentication.
+///
+/// This token is returned by Google at the end of the OAuth authentication
+/// process.
+///
+/// \param accessToken
+
+void QXmppConfiguration::setGoogleAccessToken(const QString& accessToken)
+{
+    d->googleAccessToken = accessToken;
+}
+
+/// Returns the access token used for X-MESSENGER-OAUTH2 authentication.
+
+QString QXmppConfiguration::windowsLiveAccessToken() const
+{
+    return d->windowsLiveAccessToken;
+}
+
+/// Sets the access token used for X-MESSENGER-OAUTH2 authentication.
+///
+/// This token is returned by Windows Live at the end of the OAuth authentication
+/// process.
+///
+/// \param accessToken
+
+void QXmppConfiguration::setWindowsLiveAccessToken(const QString& accessToken)
+{
+    d->windowsLiveAccessToken = accessToken;
+}
+
 /// Returns the auto-accept-subscriptions-request configuration.
 ///
 /// \return boolean value
@@ -388,25 +432,34 @@ void QXmppConfiguration::setIgnoreSslErrors(bool value)
     d->ignoreSslErrors = value;
 }
 
-/// Returns the type of authentication system specified by the user.
-/// \return true if SASL was specified else false. If the specified
-/// system is not available QXmpp will resort to the other one.
+/// Returns whether to make use of SASL authentication.
 
 bool QXmppConfiguration::useSASLAuthentication() const
 {
     return d->useSASLAuthentication;
 }
 
-/// Returns the type of authentication system specified by the user.
-/// \param useSASL to hint to use SASL authentication system if available.
-/// false will specify to use NonSASL XEP-0078: Non-SASL Authentication
-/// If the specified one is not availbe, library will use the othe one
+/// Sets whether to make use of SASL authentication.
 
 void QXmppConfiguration::setUseSASLAuthentication(bool useSASL)
 {
     d->useSASLAuthentication = useSASL;
 }
 
+/// Returns whether to make use of non-SASL authentication.
+
+bool QXmppConfiguration::useNonSASLAuthentication() const
+{
+    return d->useNonSASLAuthentication;
+}
+
+/// Sets whether to make use of non-SASL authentication.
+
+void QXmppConfiguration::setUseNonSASLAuthentication(bool useNonSASL)
+{
+    d->useNonSASLAuthentication = useNonSASL;
+}
+
 /// Returns the specified security mode for the stream. The default value is
 /// QXmppConfiguration::TLSEnabled.
 /// \return StreamSecurityMode
@@ -447,25 +500,22 @@ void QXmppConfiguration::setNonSASLAuthMechanism(
     d->nonSASLAuthMechanism = mech;
 }
 
-/// Returns the SASL authentication mechanism configuration.
-///
-/// \return QXmppConfiguration::SASLAuthMechanism
+/// Returns the preferred SASL authentication mechanism.
 ///
+/// Default value: "DIGEST-MD5"
 
-QXmppConfiguration::SASLAuthMechanism QXmppConfiguration::sASLAuthMechanism() const
+QString QXmppConfiguration::saslAuthMechanism() const
 {
-    return d->SASLAuthMechanism;
+    return d->saslAuthMechanism;
 }
 
-/// Hints the library the SASL authentication mechanism to be used for authentication.
-///
-/// \param mech QXmppConfiguration::SASLAuthMechanism
+/// Sets the preferred SASL authentication \a mechanism.
 ///
+/// Valid values: "PLAIN", "DIGEST-MD5", "ANONYMOUS", "X-FACEBOOK-PLATFORM"
 
-void QXmppConfiguration::setSASLAuthMechanism(
-        QXmppConfiguration::SASLAuthMechanism mech)
+void QXmppConfiguration::setSaslAuthMechanism(const QString &mechanism)
 {
-    d->SASLAuthMechanism = mech;
+    d->saslAuthMechanism = mechanism;
 }
 
 /// Specifies the network proxy used for the connection made by QXmppClient.
@@ -546,4 +596,3 @@ QList<QSslCertificate> QXmppConfiguration::caCertificates() const
 {
     return d->caCertificates;
 }
-
