@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2011 The QXmpp developers
+ * Copyright (C) 2008-2012 The QXmpp developers
  *
  * Author:
  *  Manjeet Dahiya
@@ -72,19 +72,6 @@ public:
     /// The server may or may not allow any particular mechanism. So depending
     /// upon the availability of mechanisms on the server the library will choose
     /// a mechanism.
-    enum SASLAuthMechanism
-    {
-        SASLPlain = 0,         ///< Plain
-        SASLDigestMD5,         ///< Digest MD5 (default)
-        SASLAnonymous,         ///< Anonymous
-        SASLXFacebookPlatform, ///< Facebook Platform
-    };
-
-    /// An enumeration for stream compression methods.
-    enum CompressionMethod
-    {
-        ZlibCompression = 0 ///< zlib compression
-    };
 
     QXmppConfiguration();
     QXmppConfiguration(const QXmppConfiguration &other);
@@ -120,6 +107,12 @@ public:
     QString facebookAppId() const;
     void setFacebookAppId(const QString&);
 
+    QString googleAccessToken() const;
+    void setGoogleAccessToken(const QString &accessToken);
+
+    QString windowsLiveAccessToken() const;
+    void setWindowsLiveAccessToken(const QString &accessToken);
+
     bool autoAcceptSubscriptions() const;
     void setAutoAcceptSubscriptions(bool);
 
@@ -129,6 +122,9 @@ public:
     bool useSASLAuthentication() const;
     void setUseSASLAuthentication(bool);
 
+    bool useNonSASLAuthentication() const;
+    void setUseNonSASLAuthentication(bool);
+
     bool ignoreSslErrors() const;
     void setIgnoreSslErrors(bool);
 
@@ -138,8 +134,8 @@ public:
     QXmppConfiguration::NonSASLAuthMechanism nonSASLAuthMechanism() const;
     void setNonSASLAuthMechanism(QXmppConfiguration::NonSASLAuthMechanism);
 
-    QXmppConfiguration::SASLAuthMechanism sASLAuthMechanism() const;
-    void setSASLAuthMechanism(QXmppConfiguration::SASLAuthMechanism);
+    QString saslAuthMechanism() const;
+    void setSaslAuthMechanism(const QString &mechanism);
 
     QNetworkProxy networkProxy() const;
     void setNetworkProxy(const QNetworkProxy& proxy);
