@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2011 The QXmpp developers
+ * Copyright (C) 2008-2012 The QXmpp developers
  *
  * Author:
  *  Manjeet Dahiya
@@ -28,6 +28,7 @@
 
 #include "QXmppClient.h"
 #include "QXmppConstants.h"
+#include "QXmppDataForm.h"
 #include "QXmppDiscoveryIq.h"
 #include "QXmppStream.h"
 #include "QXmppGlobal.h"
@@ -39,6 +40,7 @@ public:
     QString clientCategory;
     QString clientType;
     QString clientName;
+    QXmppDataForm clientInfoForm;
 };
 
 QXmppDiscoveryManager::QXmppDiscoveryManager()
@@ -58,34 +60,6 @@ QXmppDiscoveryManager::~QXmppDiscoveryManager()
     delete d;
 }
 
-bool QXmppDiscoveryManager::handleStanza(const QDomElement &element)
-{
-    if (element.tagName() == "iq" && QXmppDiscoveryIq::isDiscoveryIq(element))
-    {
-        QXmppDiscoveryIq receivedIq;
-        receivedIq.parse(element);
-
-        if(receivedIq.type() == QXmppIq::Get &&
-           receivedIq.queryType() == QXmppDiscoveryIq::InfoQuery &&
-           (receivedIq.queryNode().isEmpty() || receivedIq.queryNode().startsWith(d->clientCapabilitiesNode)))
-        {
-            // respond to query
-            QXmppDiscoveryIq qxmppFeatures = capabilities();
-            qxmppFeatures.setId(receivedIq.id());
-            qxmppFeatures.setTo(receivedIq.from());
-            qxmppFeatures.setQueryNode(receivedIq.queryNode());
-            client()->sendPacket(qxmppFeatures);
-        }
-        else if(receivedIq.queryType() == QXmppDiscoveryIq::InfoQuery)
-            emit infoReceived(receivedIq);
-        else if(receivedIq.queryType() == QXmppDiscoveryIq::ItemsQuery)
-            emit itemsReceived(receivedIq);
-
-        return true;
-    }
-    return false;
-}
-
 /// Requests information from the specified XMPP entity.
 ///
 /// \param jid  The target entity's JID.
@@ -124,10 +98,7 @@ QString QXmppDiscoveryManager::requestItems(const QString& jid, const QString& n
         return QString();
 }
 
-QStringList QXmppDiscoveryManager::discoveryFeatures() const
-{
-    return QStringList() << ns_disco_info;
-}
+/// Returns the client's full capabilities.
 
 QXmppDiscoveryIq QXmppDiscoveryManager::capabilities()
 {
@@ -138,8 +109,11 @@ QXmppDiscoveryIq QXmppDiscoveryManager::capabilities()
     // features
     QStringList features;
     features
+        << ns_data              // XEP-0004: Data Forms
+        << ns_rsm               // XEP-0059: Result Set Management
+        << ns_xhtml_im          // XEP-0071: XHTML-IM
         << ns_chat_states       // XEP-0085: Chat State Notifications
-        << ns_capabilities      // XEP-0115 : Entity Capabilities
+        << ns_capabilities      // XEP-0115: Entity Capabilities
         << ns_ping              // XEP-0199: XMPP Ping
         << ns_attention;        // XEP-0224: Attention
 
@@ -167,6 +141,11 @@ QXmppDiscoveryIq QXmppDiscoveryManager::capabilities()
     }
 
     iq.setIdentities(identities);
+
+    // extended information
+    if (!d->clientInfoForm.isNull())
+        iq.setForm(d->clientInfoForm);
+
     return iq;
 }
 
@@ -247,3 +226,69 @@ QString QXmppDiscoveryManager::clientName() const
 {
     return d->clientName;
 }
+
+/// Returns the client's extended information form, as defined
+/// by XEP-0128 Service Discovery Extensions.
+
+QXmppDataForm QXmppDiscoveryManager::clientInfoForm() const
+{
+    return d->clientInfoForm;
+}
+
+/// Sets the client's extended information form, as defined
+/// by XEP-0128 Service Discovery Extensions.
+
+void QXmppDiscoveryManager::setClientInfoForm(const QXmppDataForm &form)
+{
+    d->clientInfoForm = form;
+}
+
+/// \cond
+QStringList QXmppDiscoveryManager::discoveryFeatures() const
+{
+    return QStringList() << ns_disco_info;
+}
+
+bool QXmppDiscoveryManager::handleStanza(const QDomElement &element)
+{
+    if (element.tagName() == "iq" && QXmppDiscoveryIq::isDiscoveryIq(element))
+    {
+        QXmppDiscoveryIq receivedIq;
+        receivedIq.parse(element);
+
+        switch (receivedIq.type()) {
+        case QXmppIq::Get:
+            if (receivedIq.queryType() == QXmppDiscoveryIq::InfoQuery &&
+                (receivedIq.queryNode().isEmpty() ||
+                 receivedIq.queryNode().startsWith(d->clientCapabilitiesNode))) {
+
+                // respond to info queries for the client itself
+                QXmppDiscoveryIq qxmppFeatures = capabilities();
+                qxmppFeatures.setId(receivedIq.id());
+                qxmppFeatures.setTo(receivedIq.from());
+                qxmppFeatures.setQueryNode(receivedIq.queryNode());
+                client()->sendPacket(qxmppFeatures);
+                return true;
+            } else {
+                // let other managers handle other queries
+                return false;
+            }
+
+        case QXmppIq::Result:
+        case QXmppIq::Error:
+            // handle all replies
+            if (receivedIq.queryType() == QXmppDiscoveryIq::InfoQuery) {
+                emit infoReceived(receivedIq);
+            } else if (receivedIq.queryType() == QXmppDiscoveryIq::ItemsQuery) {
+                emit itemsReceived(receivedIq);
+            }
+            return true;
+
+        case QXmppIq::Set:
+            // let other manager handle "set" IQs
+            return false;
+        }
+    }
+    return false;
+}
+/// \endcond
