@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2011 The QXmpp developers
+ * Copyright (C) 2008-2012 The QXmpp developers
  *
  * Author:
  *  Manjeet Dahiya
@@ -26,6 +26,7 @@
 
 #include "QXmppClientExtension.h"
 
+class QXmppDataForm;
 class QXmppDiscoveryIq;
 class QXmppDiscoveryManagerPrivate;
 
@@ -42,6 +43,8 @@ public:
     QXmppDiscoveryManager();
     ~QXmppDiscoveryManager();
 
+    QXmppDiscoveryIq capabilities();
+
     QString requestInfo(const QString& jid, const QString& node = "");
     QString requestItems(const QString& jid, const QString& node = "");
 
@@ -58,10 +61,12 @@ public:
     QString clientType() const;
     void setClientType(const QString&);
 
+    QXmppDataForm clientInfoForm() const;
+    void setClientInfoForm(const QXmppDataForm &form);
+
     /// \cond
     QStringList discoveryFeatures() const;
     bool handleStanza(const QDomElement &element);
-    QXmppDiscoveryIq capabilities();
     /// \endcond
 
 signals:
